---
 layout: doc
---

# Class: auth

Management of remote authentication services

## Fields for class: auth

Class auth has no fields.

## RPCs associated with class: auth

### RPC name: get&#95;group&#95;membership

_Overview:_

This calls queries the external directory service to obtain the transitively&#45;closed set of groups that the the subject&#95;identifier is member of.

_Signature:_

```
string set get_group_membership (session ref session_ref, string subject_identifier)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`subject_identifier`          |A string containing the subject&#95;identifier, unique in the external directory service|

_Minimum Role:_ read-only

_Return Type:_ `string set`

set of subject&#95;identifiers that provides the group membership of subject&#95;identifier passed as argument, it contains, recursively, all groups a subject&#95;identifier is member of.

### RPC name: get&#95;subject&#95;identifier

_Overview:_

This call queries the external directory service to obtain the subject&#95;identifier as a string from the human&#45;readable subject&#95;name

_Signature:_

```
string get_subject_identifier (session ref session_ref, string subject_name)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`subject_name`                |The human&#45;readable subject&#95;name, such as a username or a groupname|

_Minimum Role:_ read-only

_Return Type:_ `string`

the subject&#95;identifier obtained from the external directory service

### RPC name: get&#95;subject&#95;information&#95;from&#95;identifier

_Overview:_

This call queries the external directory service to obtain the user information &#40;e.g. username, organization etc&#41; from the specified subject&#95;identifier

_Signature:_

```
(string -> string) map get_subject_information_from_identifier (session ref session_ref, string subject_identifier)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`subject_identifier`          |A string containing the subject&#95;identifier, unique in the external directory service|

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

key&#45;value pairs containing at least a key called subject&#95;name
