---
 layout: doc
---

# Class: blob

A placeholder for a binary blob

## Fields for class: blob

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`last_updated`      |`datetime`          |_RO/constructor_|Time at which the data in the blob was last updated|
|`mime_type`         |`string`            |_RO/constructor_|The mime type associated with this object. Defaults to 'application/octet&#45;stream' if the empty string is supplied|
|`name_description`  |`string`            |_RW_           |a notes field containing human&#45;readable description|
|`name_label`        |`string`            |_RW_           |a human&#45;readable name               |
|`public`            |`bool`              |_RW_           |True if the blob is publicly accessible |
|`size`              |`int`               |_RO/runtime_   |Size of the binary data, in bytes       |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: blob

### RPC name: create

_Overview:_

Create a placeholder for a binary blob

_Signature:_

```
blob ref create (session ref session_ref, string mime_type, bool public)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`mime_type`                   |The mime&#45;type of the blob. Defaults to 'application/octet&#45;stream' if the empty string is supplied|
|`bool`                        |`public`                      |True if the blob should be publicly available|

_Minimum Role:_ pool-operator

_Return Type:_ `blob ref`

The reference of the created blob

### RPC name: destroy

_Overview:_

_Signature:_

```
void destroy (session ref session_ref, blob ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`blob ref`                    |`self`                        |The reference of the blob to destroy    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the blobs known to the system.

_Signature:_

```
blob ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `blob ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of blob references to blob records for all blobs known to the system.

_Signature:_

```
(blob ref -> blob record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(blob ref -> blob record) map`

records of all objects

### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the blob instances with the given label.

_Signature:_

```
blob ref set get_by_name_label (session ref session_ref, string label)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`label`                       |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `blob ref set`

references to objects with matching names

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the blob instance with the specified UUID.

_Signature:_

```
blob ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `blob ref`

reference to the object

### RPC name: get&#95;last&#95;updated

_Overview:_

Get the last&#95;updated field of the given blob.

_Signature:_

```
datetime get_last_updated (session ref session_ref, blob ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`blob ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: get&#95;mime&#95;type

_Overview:_

Get the mime&#95;type field of the given blob.

_Signature:_

```
string get_mime_type (session ref session_ref, blob ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`blob ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given blob.

_Signature:_

```
string get_name_description (session ref session_ref, blob ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`blob ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given blob.

_Signature:_

```
string get_name_label (session ref session_ref, blob ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`blob ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;public

_Overview:_

Get the public field of the given blob.

_Signature:_

```
bool get_public (session ref session_ref, blob ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`blob ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given blob.

_Signature:_

```
blob record get_record (session ref session_ref, blob ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`blob ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `blob record`

all fields from the object

### RPC name: get&#95;size

_Overview:_

Get the size field of the given blob.

_Signature:_

```
int get_size (session ref session_ref, blob ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`blob ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given blob.

_Signature:_

```
string get_uuid (session ref session_ref, blob ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`blob ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given blob.

_Signature:_

```
void set_name_description (session ref session_ref, blob ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`blob ref`                    |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given blob.

_Signature:_

```
void set_name_label (session ref session_ref, blob ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`blob ref`                    |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;public

_Overview:_

Set the public field of the given blob.

_Signature:_

```
void set_public (session ref session_ref, blob ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`blob ref`                    |`self`                        |reference to the object                 |
|`bool`                        |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`
