---
 layout: doc
---

# Class: Cluster

Cluster&#45;wide Cluster metadata

## Fields for class: Cluster

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`allowed_operations`|`cluster_operation set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|`cluster_config`    |`(string -> string) map`|_RO/constructor_|Contains read&#45;only settings for the cluster, such as timeouts and other options. It can only be set at cluster create time|
|`cluster_hosts`     |`Cluster_host ref set`|_RO/runtime_   |A list of the cluster&#95;host objects associated with the Cluster|
|`cluster_stack`     |`string`            |_RO/constructor_|Simply the string 'corosync'. No other cluster stacks are currently supported|
|`cluster_token`     |`string`            |_RO/constructor_|The secret key used by xapi&#45;clusterd when it talks to itself on other hosts|
|`current_operations`|`(string -> cluster_operation) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|`is_quorate`        |`bool`              |_RO/runtime_   |Whether the cluster stack thinks the cluster is quorate|
|`live_hosts`        |`int`               |_RO/runtime_   |Current number of live hosts, according to the cluster stack|
|`other_config`      |`(string -> string) map`|_RW_           |Additional configuration                |
|`pending_forget`    |`string set`        |_RO/runtime_   |Internal field used by Host.destroy to store the IP of cluster members marked as permanently dead but not yet removed|
|`pool_auto_join`    |`bool`              |_RO/constructor_|True if automatically joining new pool members to the cluster. This will be `true` in the first release|
|`quorum`            |`int`               |_RO/runtime_   |Number of live hosts in order to be quorate|
|`token_timeout`     |`float`             |_RO/constructor_|The corosync token timeout in seconds   |
|`token_timeout_coefficient`|`float`             |_RO/constructor_|The corosync token timeout coefficient in seconds|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: Cluster

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given Cluster.

_Signature:_

```
void add_to_other_config (session ref session_ref, Cluster ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: create

_Overview:_

Creates a Cluster object and one Cluster&#95;host object as its first member

_Signature:_

```
Cluster ref create (session ref session_ref, PIF ref PIF, string cluster_stack, bool pool_auto_join, float token_timeout, float token_timeout_coefficient)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`PIF`                         |The PIF to connect the cluster's first cluster&#95;host to|
|`string`                      |`cluster_stack`               |simply the string 'corosync'. No other cluster stacks are currently supported|
|`bool`                        |`pool_auto_join`              |true if xapi is automatically joining new pool members to the cluster|
|`float`                       |`token_timeout`               |Corosync token timeout in seconds       |
|`float`                       |`token_timeout_coefficient`   |Corosync token timeout coefficient in seconds|

_Minimum Role:_ pool-operator

_Return Type:_ `Cluster ref`

the new Cluster

_Possible Error Codes:_ `INVALID_CLUSTER_STACK`, `INVALID_VALUE`, `PIF_ALLOWS_UNPLUG`, `REQUIRED_PIF_IS_UNPLUGGED`

### RPC name: destroy

_Overview:_

Destroys a Cluster object and the one remaining Cluster&#95;host member

_Signature:_

```
void destroy (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |the Cluster to destroy                  |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `CLUSTER_DOES_NOT_HAVE_ONE_NODE`, `CLUSTER_STACK_IN_USE`

### RPC name: get&#95;all

_Overview:_

Return a list of all the Clusters known to the system.

_Signature:_

```
Cluster ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `Cluster ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of Cluster references to Cluster records for all Clusters known to the system.

_Signature:_

```
(Cluster ref -> Cluster record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(Cluster ref -> Cluster record) map`

records of all objects

### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given Cluster.

_Signature:_

```
cluster_operation set get_allowed_operations (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `cluster_operation set`

value of the field

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the Cluster instance with the specified UUID.

_Signature:_

```
Cluster ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `Cluster ref`

reference to the object

### RPC name: get&#95;cluster&#95;config

_Overview:_

Get the cluster&#95;config field of the given Cluster.

_Signature:_

```
(string -> string) map get_cluster_config (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;cluster&#95;hosts

_Overview:_

Get the cluster&#95;hosts field of the given Cluster.

_Signature:_

```
Cluster_host ref set get_cluster_hosts (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Cluster_host ref set`

value of the field

### RPC name: get&#95;cluster&#95;stack

_Overview:_

Get the cluster&#95;stack field of the given Cluster.

_Signature:_

```
string get_cluster_stack (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;cluster&#95;token

_Overview:_

Get the cluster&#95;token field of the given Cluster.

_Signature:_

```
string get_cluster_token (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given Cluster.

_Signature:_

```
(string -> cluster_operation) map get_current_operations (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> cluster_operation) map`

value of the field

### RPC name: get&#95;is&#95;quorate

_Overview:_

Get the is&#95;quorate field of the given Cluster.

_Signature:_

```
bool get_is_quorate (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;live&#95;hosts

_Overview:_

Get the live&#95;hosts field of the given Cluster.

_Signature:_

```
int get_live_hosts (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;network

_Overview:_

Returns the network used by the cluster for inter&#45;host communication, i.e. the network shared by all cluster host PIFs

_Signature:_

```
network ref get_network (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |the Cluster with the network            |

_Minimum Role:_ read-only

_Return Type:_ `network ref`

network of cluster

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given Cluster.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;pending&#95;forget

_Overview:_

Get the pending&#95;forget field of the given Cluster.

_Signature:_

```
string set get_pending_forget (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;pool&#95;auto&#95;join

_Overview:_

Get the pool&#95;auto&#95;join field of the given Cluster.

_Signature:_

```
bool get_pool_auto_join (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;quorum

_Overview:_

Get the quorum field of the given Cluster.

_Signature:_

```
int get_quorum (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given Cluster.

_Signature:_

```
Cluster record get_record (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Cluster record`

all fields from the object

### RPC name: get&#95;token&#95;timeout

_Overview:_

Get the token&#95;timeout field of the given Cluster.

_Signature:_

```
float get_token_timeout (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `float`

value of the field

### RPC name: get&#95;token&#95;timeout&#95;coefficient

_Overview:_

Get the token&#95;timeout&#95;coefficient field of the given Cluster.

_Signature:_

```
float get_token_timeout_coefficient (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `float`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given Cluster.

_Signature:_

```
string get_uuid (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: pool&#95;create

_Overview:_

Attempt to create a Cluster from the entire pool

_Signature:_

```
Cluster ref pool_create (session ref session_ref, network ref network, string cluster_stack, float token_timeout, float token_timeout_coefficient)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`network`                     |the single network on which corosync carries out its inter&#45;host communications|
|`string`                      |`cluster_stack`               |simply the string 'corosync'. No other cluster stacks are currently supported|
|`float`                       |`token_timeout`               |Corosync token timeout in seconds       |
|`float`                       |`token_timeout_coefficient`   |Corosync token timeout coefficient in seconds|

_Minimum Role:_ pool-operator

_Return Type:_ `Cluster ref`

the new Cluster

### RPC name: pool&#95;destroy

_Overview:_

Attempt to destroy the Cluster&#95;host objects for all hosts in the pool and then destroy the Cluster.

_Signature:_

```
void pool_destroy (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |The cluster to destroy.                 |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `CLUSTER_STACK_IN_USE`, `CLUSTERING_DISABLED`, `CLUSTER_HOST_IS_LAST`

### RPC name: pool&#95;force&#95;destroy

_Overview:_

Attempt to force destroy the Cluster&#95;host objects, and then destroy the Cluster.

_Signature:_

```
void pool_force_destroy (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |The cluster to force destroy.           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `CLUSTER_FORCE_DESTROY_FAILED`

### RPC name: pool&#95;resync

_Overview:_

Resynchronise the cluster&#95;host objects across the pool. Creates them where they need creating and then plugs them

_Signature:_

```
void pool_resync (session ref session_ref, Cluster ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |The cluster to resync                   |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given Cluster.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, Cluster ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given Cluster.

_Signature:_

```
void set_other_config (session ref session_ref, Cluster ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Cluster ref`                 |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`
