---
 layout: doc
---

# Class: DR&#95;task

DR task

## Fields for class: DR&#95;task

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`introduced_SRs`    |`SR ref set`        |_RO/runtime_   |All SRs introduced by this appliance    |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: DR&#95;task

### RPC name: create

_Overview:_

Create a disaster recovery task which will query the supplied list of devices

_Signature:_

```
DR_task ref create (session ref session_ref, string type, (string -> string) map device_config, string set whitelist)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`type`                        |The SR driver type of the SRs to introduce|
|`(string -> string) map`      |`device_config`               |The device configuration of the SRs to introduce|
|`string set`                  |`whitelist`                   |The devices to use for disaster recovery|

_Minimum Role:_ pool-operator

_Return Type:_ `DR_task ref`

The reference of the created DR&#95;task

### RPC name: destroy

_Overview:_

Destroy the disaster recovery task, detaching and forgetting any SRs introduced which are no longer required

_Signature:_

```
void destroy (session ref session_ref, DR_task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`DR_task ref`                 |`self`                        |The disaster recovery task to destroy   |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the DR&#95;tasks known to the system.

_Signature:_

```
DR_task ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `DR_task ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of DR&#95;task references to DR&#95;task records for all DR&#95;tasks known to the system.

_Signature:_

```
(DR_task ref -> DR_task record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(DR_task ref -> DR_task record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the DR&#95;task instance with the specified UUID.

_Signature:_

```
DR_task ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `DR_task ref`

reference to the object

### RPC name: get&#95;introduced&#95;SRs

_Overview:_

Get the introduced&#95;SRs field of the given DR&#95;task.

_Signature:_

```
SR ref set get_introduced_SRs (session ref session_ref, DR_task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`DR_task ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref set`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given DR&#95;task.

_Signature:_

```
DR_task record get_record (session ref session_ref, DR_task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`DR_task ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `DR_task record`

all fields from the object

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given DR&#95;task.

_Signature:_

```
string get_uuid (session ref session_ref, DR_task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`DR_task ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field
