---
 layout: doc
---

# Class: GPU&#95;group

A group of compatible GPUs across the resource pool

## Fields for class: GPU&#95;group

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`allocation_algorithm`|`allocation_algorithm`|_RW_           |Current allocation of vGPUs to pGPUs for this group|
|`enabled_VGPU_types`|`VGPU_type ref set` |_RO/runtime_   |vGPU types supported on at least one of the pGPUs in this group|
|`GPU_types`         |`string set`        |_RO/runtime_   |List of GPU types &#40;vendor&#43;device ID&#41; that can be in this group|
|`name_description`  |`string`            |_RW_           |a notes field containing human&#45;readable description|
|`name_label`        |`string`            |_RW_           |a human&#45;readable name               |
|`other_config`      |`(string -> string) map`|_RW_           |Additional configuration                |
|`PGPUs`             |`PGPU ref set`      |_RO/runtime_   |List of pGPUs in the group              |
|`supported_VGPU_types`|`VGPU_type ref set` |_RO/runtime_   |vGPU types supported on at least one of the pGPUs in this group|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`VGPUs`             |`VGPU ref set`      |_RO/runtime_   |List of vGPUs using the group           |

## RPCs associated with class: GPU&#95;group

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given GPU&#95;group.

_Signature:_

```
void add_to_other_config (session ref session_ref, GPU_group ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`GPU_group ref`               |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: create

_Overview:_

_Signature:_

```
GPU_group ref create (session ref session_ref, string name_label, string name_description, (string -> string) map other_config)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`name_label`                  |                                        |
|`string`                      |`name_description`            |                                        |
|`(string -> string) map`      |`other_config`                |                                        |

_Minimum Role:_ pool-operator

_Return Type:_ `GPU_group ref`

The reference of the created GPU&#95;group

### RPC name: destroy

_Overview:_

_Signature:_

```
void destroy (session ref session_ref, GPU_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`GPU_group ref`               |`self`                        |The GPU group to destroy                |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the GPU&#95;groups known to the system.

_Signature:_

```
GPU_group ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `GPU_group ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of GPU&#95;group references to GPU&#95;group records for all GPU&#95;groups known to the system.

_Signature:_

```
(GPU_group ref -> GPU_group record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(GPU_group ref -> GPU_group record) map`

records of all objects

### RPC name: get&#95;allocation&#95;algorithm

_Overview:_

Get the allocation&#95;algorithm field of the given GPU&#95;group.

_Signature:_

```
allocation_algorithm get_allocation_algorithm (session ref session_ref, GPU_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`GPU_group ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `allocation_algorithm`

value of the field

### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the GPU&#95;group instances with the given label.

_Signature:_

```
GPU_group ref set get_by_name_label (session ref session_ref, string label)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`label`                       |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `GPU_group ref set`

references to objects with matching names

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the GPU&#95;group instance with the specified UUID.

_Signature:_

```
GPU_group ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `GPU_group ref`

reference to the object

### RPC name: get&#95;enabled&#95;VGPU&#95;types

_Overview:_

Get the enabled&#95;VGPU&#95;types field of the given GPU&#95;group.

_Signature:_

```
VGPU_type ref set get_enabled_VGPU_types (session ref session_ref, GPU_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`GPU_group ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU_type ref set`

value of the field

### RPC name: get&#95;GPU&#95;types

_Overview:_

Get the GPU&#95;types field of the given GPU&#95;group.

_Signature:_

```
string set get_GPU_types (session ref session_ref, GPU_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`GPU_group ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given GPU&#95;group.

_Signature:_

```
string get_name_description (session ref session_ref, GPU_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`GPU_group ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given GPU&#95;group.

_Signature:_

```
string get_name_label (session ref session_ref, GPU_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`GPU_group ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given GPU&#95;group.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, GPU_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`GPU_group ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;PGPUs

_Overview:_

Get the PGPUs field of the given GPU&#95;group.

_Signature:_

```
PGPU ref set get_PGPUs (session ref session_ref, GPU_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`GPU_group ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PGPU ref set`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given GPU&#95;group.

_Signature:_

```
GPU_group record get_record (session ref session_ref, GPU_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`GPU_group ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `GPU_group record`

all fields from the object

### RPC name: get&#95;remaining&#95;capacity

_Overview:_

_Signature:_

```
int get_remaining_capacity (session ref session_ref, GPU_group ref self, VGPU_type ref vgpu_type)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`GPU_group ref`               |`self`                        |The GPU group to query                  |
|`VGPU_type ref`               |`vgpu_type`                   |The VGPU&#95;type for which the remaining capacity will be calculated|

_Minimum Role:_ read-only

_Return Type:_ `int`

The number of VGPUs of the given type which can still be started on the PGPUs in the group

### RPC name: get&#95;supported&#95;VGPU&#95;types

_Overview:_

Get the supported&#95;VGPU&#95;types field of the given GPU&#95;group.

_Signature:_

```
VGPU_type ref set get_supported_VGPU_types (session ref session_ref, GPU_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`GPU_group ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU_type ref set`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given GPU&#95;group.

_Signature:_

```
string get_uuid (session ref session_ref, GPU_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`GPU_group ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;VGPUs

_Overview:_

Get the VGPUs field of the given GPU&#95;group.

_Signature:_

```
VGPU ref set get_VGPUs (session ref session_ref, GPU_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`GPU_group ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU ref set`

value of the field

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given GPU&#95;group.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, GPU_group ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`GPU_group ref`               |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;allocation&#95;algorithm

_Overview:_

Set the allocation&#95;algorithm field of the given GPU&#95;group.

_Signature:_

```
void set_allocation_algorithm (session ref session_ref, GPU_group ref self, allocation_algorithm value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`GPU_group ref`               |`self`                        |reference to the object                 |
|`allocation_algorithm`        |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given GPU&#95;group.

_Signature:_

```
void set_name_description (session ref session_ref, GPU_group ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`GPU_group ref`               |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given GPU&#95;group.

_Signature:_

```
void set_name_label (session ref session_ref, GPU_group ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`GPU_group ref`               |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given GPU&#95;group.

_Signature:_

```
void set_other_config (session ref session_ref, GPU_group ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`GPU_group ref`               |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`
