---
 layout: doc
---

# Class: host

A physical host

## Fields for class: host

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`address`           |`string`            |_RW_           |The address by which this host can be contacted from any other host in the pool|
|`allowed_operations`|`host_allowed_operations set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|`API_version_major` |`int`               |_RO/runtime_   |major version number                    |
|`API_version_minor` |`int`               |_RO/runtime_   |minor version number                    |
|`API_version_vendor`|`string`            |_RO/runtime_   |identification of vendor                |
|`API_version_vendor_implementation`|`(string -> string) map`|_RO/runtime_   |details of vendor implementation        |
|`bios_strings`      |`(string -> string) map`|_RO/runtime_   |BIOS strings                            |
|`blobs`             |`(string -> blob ref) map`|_RO/runtime_   |Binary blobs associated with this host  |
|`capabilities`      |`string set`        |_RO/constructor_|Xen capabilities                        |
|`certificates`      |`Certificate ref set`|_RO/runtime_   |List of certificates installed in the host|
|`chipset_info`      |`(string -> string) map`|_RO/runtime_   |Information about chipset features      |
|`control_domain`    |`VM ref`            |_RO/runtime_   |The control domain &#40;domain 0&#41;   |
|`cpu_configuration` |`(string -> string) map`|_RO/runtime_   |The CPU configuration on this host.  May contain keys such as "nr&#95;nodes", "sockets&#95;per&#95;node", "cores&#95;per&#95;socket", or "threads&#95;per&#95;core"|
|`cpu_info`          |`(string -> string) map`|_RO/runtime_   |Details about the physical CPUs on this host|
|`crash_dump_sr`     |`SR ref`            |_RW_           |The SR in which VDIs for crash dumps are created|
|`crashdumps`        |`host_crashdump ref set`|_RO/runtime_   |Set of host crash dumps                 |
|`current_operations`|`(string -> host_allowed_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|`display`           |`host_display`      |_RW_           |indicates whether the host is configured to output its console to a physical display device|
|`edition`           |`string`            |_RO/runtime_   |Product edition                         |
|`editions`          |`string set`        |_RO/runtime_   |List of all available product editions  |
|`enabled`           |`bool`              |_RO/runtime_   |True if the host is currently enabled   |
|`external_auth_configuration`|`(string -> string) map`|_RO/runtime_   |configuration specific to external authentication service|
|`external_auth_service_name`|`string`            |_RO/runtime_   |name of external authentication service configured; empty if none configured.|
|`external_auth_type`|`string`            |_RO/runtime_   |type of external authentication service configured; empty if none configured.|
|`features`          |`Feature ref set`   |_RO/runtime_   |List of features available on this host |
|`guest_VCPUs_params`|`(string -> string) map`|_RW_           |VCPUs params to apply to all resident guests|
|`ha_network_peers`  |`string set`        |_RO/runtime_   |The set of hosts visible via the network from this host|
|`ha_statefiles`     |`string set`        |_RO/runtime_   |The set of statefiles accessible from this host|
|`host_CPUs`         |`host_cpu ref set`  |_RO/runtime_   |The physical CPUs on this host          |
|`hostname`          |`string`            |_RW_           |The hostname of this host               |
|`https_only`        |`bool`              |_RO/runtime_   |Reflects whether port 80 is open &#40;false&#41; or not &#40;true&#41;|
|`iscsi_iqn`         |`string`            |_RO/constructor_|The initiator IQN for the host          |
|`last_software_update`|`datetime`          |_RO/runtime_   |Date and time when the last software update was applied|
|`last_update_hash`  |`string`            |_RO/runtime_   |The SHA256 checksum of updateinfo of the most recently applied update on the host|
|`latest_synced_updates_applied`|`latest_synced_updates_applied_state`|_RO/runtime_   |Default as 'unknown', 'yes' if the host is up to date with updates synced from remote CDN, otherwise 'no'|
|`license_params`    |`(string -> string) map`|_RO/runtime_   |State of the current license            |
|`license_server`    |`(string -> string) map`|_RW_           |Contact information of the license server|
|`local_cache_sr`    |`SR ref`            |_RO/constructor_|The SR that is used as a local cache    |
|`logging`           |`(string -> string) map`|_RW_           |logging configuration                   |
|`memory_overhead`   |`int`               |_RO/runtime_   |Virtualization memory overhead &#40;bytes&#41;.|
|`metrics`           |`host_metrics ref`  |_RO/runtime_   |metrics associated with this host       |
|`multipathing`      |`bool`              |_RO/constructor_|Specifies whether multipathing is enabled|
|`name_description`  |`string`            |_RW_           |a notes field containing human&#45;readable description|
|`name_label`        |`string`            |_RW_           |a human&#45;readable name               |
|`numa_affinity_policy`|`host_numa_affinity_policy`|_RO/runtime_   |NUMA&#45;aware VM memory and vCPU placement policy|
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`patches`           |`host_patch ref set`|_RO/runtime_   |**Deprecated.** Set of host patches                     |
|`PBDs`              |`PBD ref set`       |_RO/runtime_   |physical blockdevices                   |
|`PCIs`              |`PCI ref set`       |_RO/runtime_   |List of PCI devices in the host         |
|`pending_guidances` |`update_guidances set`|_RO/runtime_   |The set of pending mandatory guidances after applying updates, which must be applied, as otherwise there may be e.g. VM failures|
|`pending_guidances_full`|`update_guidances set`|_RO/runtime_   |The set of pending full guidances after applying updates, which a user should follow to make some updates, e.g. specific hardware drivers or CPU features, fully effective, but the 'average user' doesn't need to|
|`pending_guidances_recommended`|`update_guidances set`|_RO/runtime_   |The set of pending recommended guidances after applying updates, which most users should follow to make the updates effective, but if not followed, will not cause a failure|
|`PGPUs`             |`PGPU ref set`      |_RO/runtime_   |List of physical GPUs in the host       |
|`PIFs`              |`PIF ref set`       |_RO/runtime_   |physical network interfaces             |
|`power_on_config`   |`(string -> string) map`|_RO/runtime_   |The power on config                     |
|`power_on_mode`     |`string`            |_RO/runtime_   |The power on mode                       |
|`PUSBs`             |`PUSB ref set`      |_RO/runtime_   |List of physical USBs in the host       |
|`resident_VMs`      |`VM ref set`        |_RO/runtime_   |list of VMs currently resident on host  |
|`sched_policy`      |`string`            |_RO/runtime_   |Scheduler policy currently in force on this host|
|`software_version`  |`(string -> string) map`|_RO/constructor_|version strings                         |
|`ssl_legacy`        |`bool`              |_RO/constructor_|**Deprecated.** Allow SSLv3 protocol and ciphersuites as used by older server versions. This controls both incoming and outgoing connections. When this is set to a different value, the host immediately restarts its SSL/TLS listening service; typically this takes less than a second but existing connections to it will be broken. API login sessions will remain valid.|
|`supported_bootloaders`|`string set`        |_RO/runtime_   |a list of the bootloaders installed on the machine|
|`suspend_image_sr`  |`SR ref`            |_RW_           |The SR in which VDIs for suspend images are created|
|`tags`              |`string set`        |_RW_           |user&#45;specified tags for categorization purposes|
|`tls_verification_enabled`|`bool`              |_RO/runtime_   |True if this host has TLS verifcation enabled|
|`uefi_certificates` |`string`            |_RO/constructor_|**Deprecated.** The UEFI certificates allowing Secure Boot|
|`updates`           |`pool_update ref set`|_RO/runtime_   |Set of updates                          |
|`updates_requiring_reboot`|`pool_update ref set`|_RO/runtime_   |List of updates which require reboot    |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`virtual_hardware_platform_versions`|`int set`           |_RO/runtime_   |The set of versions of the virtual hardware platform that the host can offer to its guests|

## RPCs associated with class: host

### RPC name: add&#95;tags

_Overview:_

Add the given value to the tags field of the given host.  If the value is already in that Set, then do nothing.

_Signature:_

```
void add_tags (session ref session_ref, host ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to add                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

### RPC name: add&#95;to&#95;guest&#95;VCPUs&#95;params

_Overview:_

Add the given key&#45;value pair to the guest&#95;VCPUs&#95;params field of the given host.

_Signature:_

```
void add_to_guest_VCPUs_params (session ref session_ref, host ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: add&#95;to&#95;license&#95;server

_Overview:_

Add the given key&#45;value pair to the license&#95;server field of the given host.

_Signature:_

```
void add_to_license_server (session ref session_ref, host ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: add&#95;to&#95;logging

_Overview:_

Add the given key&#45;value pair to the logging field of the given host.

_Signature:_

```
void add_to_logging (session ref session_ref, host ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given host.

_Signature:_

```
void add_to_other_config (session ref session_ref, host ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: apply&#95;edition

_Overview:_

Change to another edition, or reactivate the current edition after a license has expired. This may be subject to the successful checkout of an appropriate license.

_Signature:_

```
void apply_edition (session ref session_ref, host ref host, string edition, bool force)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |
|`string`                      |`edition`                     |The requested edition                   |
|`bool`                        |`force`                       |Update the license params even if the apply call fails|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: apply&#95;recommended&#95;guidances

**This message is removed.**

_Overview:_

apply all recommended guidances both on the host and on all HVM VMs on the host after updates are applied on the host

_Signature:_

```
void apply_recommended_guidances (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |The host whose recommended guidances will be applied|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: apply&#95;updates

_Overview:_

apply updates from current enabled repository on a host

_Signature:_

```
string set set apply_updates (session ref session_ref, host ref self, string hash)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |The host where updates will be applied  |
|`string`                      |`hash`                        |The hash of updateinfo to be applied which is returned by previous pool.sync&#95;udpates|

_Minimum Role:_ client-cert

_Return Type:_ `string set set`

The list of results after applying updates, including livepatch apply failures and recommended guidances

### RPC name: assert&#95;can&#95;evacuate

_Overview:_

Check this host can be evacuated.

_Signature:_

```
void assert_can_evacuate (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host to evacuate                    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: backup&#95;rrds

_Overview:_

This causes the RRDs to be backed up to the master

_Signature:_

```
void backup_rrds (session ref session_ref, host ref host, float delay)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |Schedule a backup of the RRDs of this host|
|`float`                       |`delay`                       |Delay in seconds from when the call is received to perform the backup|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: bugreport&#95;upload

_Overview:_

Run xen&#45;bugtool &#45;&#45;yestoall and upload the output to support

_Signature:_

```
void bugreport_upload (session ref session_ref, host ref host, string url, (string -> string) map options)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host on which to run xen&#45;bugtool|
|`string`                      |`url`                         |The URL to upload to                    |
|`(string -> string) map`      |`options`                     |Extra configuration operations          |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: call&#95;extension

_Overview:_

Call an API extension on this host

_Signature:_

```
string call_extension (session ref session_ref, host ref host, string call)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |
|`string`                      |`call`                        |Rpc call for the extension              |

_Minimum Role:_ pool-admin

_Return Type:_ `string`

Result from the extension

### RPC name: call&#95;plugin

_Overview:_

Call an API plugin on this host

_Signature:_

```
string call_plugin (session ref session_ref, host ref host, string plugin, string fn, (string -> string) map args)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |
|`string`                      |`plugin`                      |The name of the plugin                  |
|`string`                      |`fn`                          |The name of the function within the plugin|
|`(string -> string) map`      |`args`                        |Arguments for the function              |

_Minimum Role:_ pool-admin

_Return Type:_ `string`

Result from the plugin

### RPC name: compute&#95;free&#95;memory

_Overview:_

Computes the amount of free memory on the host.

_Signature:_

```
int compute_free_memory (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host to send the request to         |

_Minimum Role:_ read-only

_Return Type:_ `int`

the amount of free memory on the host.

### RPC name: compute&#95;memory&#95;overhead

_Overview:_

Computes the virtualization memory overhead of a host.

_Signature:_

```
int compute_memory_overhead (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host for which to compute the memory overhead|

_Minimum Role:_ read-only

_Return Type:_ `int`

the virtualization memory overhead of the host.

### RPC name: create&#95;new&#95;blob

_Overview:_

Create a placeholder for a named binary blob of data that is associated with this host

_Signature:_

```
blob ref create_new_blob (session ref session_ref, host ref host, string name, string mime_type, bool public)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |
|`string`                      |`name`                        |The name associated with the blob       |
|`string`                      |`mime_type`                   |The mime type for the data. Empty string translates to application/octet&#45;stream|
|`bool`                        |`public`                      |True if the blob should be publicly available|

_Minimum Role:_ pool-operator

_Return Type:_ `blob ref`

The reference of the blob, needed for populating its data

### RPC name: declare&#95;dead

_Overview:_

Declare that a host is dead. This is a dangerous operation, and should only be called if the administrator is absolutely sure the host is definitely dead

_Signature:_

```
void declare_dead (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The Host to declare is dead             |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: destroy

_Overview:_

Destroy specified host record in database

_Signature:_

```
void destroy (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |The host record to remove               |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: disable

_Overview:_

Puts the host into a state in which no new VMs can be started. Currently active VMs on the host continue to execute.

_Signature:_

```
void disable (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The Host to disable                     |

_Minimum Role:_ client-cert

_Return Type:_ `void`

### RPC name: disable&#95;display

_Overview:_

Disable console output to the physical display device next time this host boots

_Signature:_

```
host_display disable_display (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |

_Minimum Role:_ pool-operator

_Return Type:_ `host_display`

This host's physical display usage

### RPC name: disable&#95;external&#95;auth

_Overview:_

This call disables external authentication on the local host

_Signature:_

```
void disable_external_auth (session ref session_ref, host ref host, (string -> string) map config)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host whose external authentication should be disabled|
|`(string -> string) map`      |`config`                      |Optional parameters as a list of key&#45;values containing the configuration data|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: disable&#95;local&#95;storage&#95;caching

_Overview:_

Disable the use of a local SR for caching purposes

_Signature:_

```
void disable_local_storage_caching (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: dmesg

_Overview:_

Get the host xen dmesg.

_Signature:_

```
string dmesg (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The Host to query                       |

_Minimum Role:_ pool-operator

_Return Type:_ `string`

dmesg string

### RPC name: dmesg&#95;clear

_Overview:_

Get the host xen dmesg, and clear the buffer.

_Signature:_

```
string dmesg_clear (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The Host to query                       |

_Minimum Role:_ pool-operator

_Return Type:_ `string`

dmesg string

### RPC name: emergency&#95;clear&#95;mandatory&#95;guidance

_Overview:_

Clear the pending mandatory guidance on this host

_Signature:_

```
void emergency_clear_mandatory_guidance (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Return Type:_ `void`

### RPC name: emergency&#95;disable&#95;tls&#95;verification

_Overview:_

Disable TLS verification for this host only

_Signature:_

```
void emergency_disable_tls_verification (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Return Type:_ `void`

### RPC name: emergency&#95;ha&#95;disable

_Overview:_

This call disables HA on the local host. This should only be used with extreme care.

_Signature:_

```
void emergency_ha_disable (session ref session_ref, bool soft)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`bool`                        |`soft`                        |Disable HA temporarily, revert upon host reboot or further changes, idempotent|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: emergency&#95;reenable&#95;tls&#95;verification

_Overview:_

Reenable TLS verification for this host only

_Signature:_

```
void emergency_reenable_tls_verification (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Return Type:_ `void`

### RPC name: emergency&#95;reset&#95;server&#95;certificate

_Overview:_

Delete the current TLS server certificate and replace by a new, self&#45;signed one. This should only be used with extreme care.

_Signature:_

```
void emergency_reset_server_certificate (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Return Type:_ `void`

### RPC name: enable

_Overview:_

Puts the host into a state in which new VMs can be started.

_Signature:_

```
void enable (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The Host to enable                      |

_Minimum Role:_ client-cert

_Return Type:_ `void`

### RPC name: enable&#95;display

_Overview:_

Enable console output to the physical display device next time this host boots

_Signature:_

```
host_display enable_display (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |

_Minimum Role:_ pool-operator

_Return Type:_ `host_display`

This host's physical display usage

### RPC name: enable&#95;external&#95;auth

_Overview:_

This call enables external authentication on a host

_Signature:_

```
void enable_external_auth (session ref session_ref, host ref host, (string -> string) map config, string service_name, string auth_type)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host whose external authentication should be enabled|
|`(string -> string) map`      |`config`                      |A list of key&#45;values containing the configuration data|
|`string`                      |`service_name`                |The name of the service                 |
|`string`                      |`auth_type`                   |The type of authentication &#40;e.g. AD for Active Directory&#41;|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: enable&#95;local&#95;storage&#95;caching

_Overview:_

Enable the use of a local SR for caching purposes

_Signature:_

```
void enable_local_storage_caching (session ref session_ref, host ref host, SR ref sr)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |
|`SR ref`                      |`sr`                          |The SR to use as a local cache          |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: evacuate

_Overview:_

Migrate all VMs off of this host, where possible.

_Signature:_

```
void evacuate (session ref session_ref, host ref host, network ref network, int evacuate_batch_size)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host to evacuate                    |
|`network ref`                 |`network`                     |Optional preferred network for migration|
|`int`                         |`evacuate_batch_size`         |The maximum number of VMs to be migrated per batch 0 will use the value `evacuation&#45;batch&#45;size` defined in xapi.conf|

_Minimum Role:_ client-cert

_Return Type:_ `void`

### RPC name: forget&#95;data&#95;source&#95;archives

_Overview:_

Forget the recorded statistics related to the specified data source

_Signature:_

```
void forget_data_source_archives (session ref session_ref, host ref host, string data_source)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |
|`string`                      |`data_source`                 |The data source whose archives are to be forgotten|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;address

_Overview:_

Get the address field of the given host.

_Signature:_

```
string get_address (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;all

_Overview:_

Return a list of all the hosts known to the system.

_Signature:_

```
host ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `host ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of host references to host records for all hosts known to the system.

_Signature:_

```
(host ref -> host record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(host ref -> host record) map`

records of all objects

### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given host.

_Signature:_

```
host_allowed_operations set get_allowed_operations (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_allowed_operations set`

value of the field

### RPC name: get&#95;API&#95;version&#95;major

_Overview:_

Get the API&#95;version/major field of the given host.

_Signature:_

```
int get_API_version_major (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;API&#95;version&#95;minor

_Overview:_

Get the API&#95;version/minor field of the given host.

_Signature:_

```
int get_API_version_minor (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;API&#95;version&#95;vendor

_Overview:_

Get the API&#95;version/vendor field of the given host.

_Signature:_

```
string get_API_version_vendor (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;API&#95;version&#95;vendor&#95;implementation

_Overview:_

Get the API&#95;version/vendor&#95;implementation field of the given host.

_Signature:_

```
(string -> string) map get_API_version_vendor_implementation (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;bios&#95;strings

_Overview:_

Get the bios&#95;strings field of the given host.

_Signature:_

```
(string -> string) map get_bios_strings (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;blobs

_Overview:_

Get the blobs field of the given host.

_Signature:_

```
(string -> blob ref) map get_blobs (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> blob ref) map`

value of the field

### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the host instances with the given label.

_Signature:_

```
host ref set get_by_name_label (session ref session_ref, string label)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`label`                       |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `host ref set`

references to objects with matching names

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the host instance with the specified UUID.

_Signature:_

```
host ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

reference to the object

### RPC name: get&#95;capabilities

_Overview:_

Get the capabilities field of the given host.

_Signature:_

```
string set get_capabilities (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;certificates

_Overview:_

Get the certificates field of the given host.

_Signature:_

```
Certificate ref set get_certificates (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Certificate ref set`

value of the field

### RPC name: get&#95;chipset&#95;info

_Overview:_

Get the chipset&#95;info field of the given host.

_Signature:_

```
(string -> string) map get_chipset_info (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;control&#95;domain

_Overview:_

Get the control&#95;domain field of the given host.

_Signature:_

```
VM ref get_control_domain (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

value of the field

### RPC name: get&#95;cpu&#95;configuration

_Overview:_

Get the cpu&#95;configuration field of the given host.

_Signature:_

```
(string -> string) map get_cpu_configuration (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;cpu&#95;info

_Overview:_

Get the cpu&#95;info field of the given host.

_Signature:_

```
(string -> string) map get_cpu_info (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;crash&#95;dump&#95;sr

_Overview:_

Get the crash&#95;dump&#95;sr field of the given host.

_Signature:_

```
SR ref get_crash_dump_sr (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

value of the field

### RPC name: get&#95;crashdumps

_Overview:_

Get the crashdumps field of the given host.

_Signature:_

```
host_crashdump ref set get_crashdumps (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_crashdump ref set`

value of the field

### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given host.

_Signature:_

```
(string -> host_allowed_operations) map get_current_operations (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> host_allowed_operations) map`

value of the field

### RPC name: get&#95;data&#95;sources

_Overview:_

_Signature:_

```
data_source record set get_data_sources (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host to interrogate                 |

_Minimum Role:_ read-only

_Return Type:_ `data_source record set`

A set of data sources

### RPC name: get&#95;display

_Overview:_

Get the display field of the given host.

_Signature:_

```
host_display get_display (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_display`

value of the field

### RPC name: get&#95;edition

_Overview:_

Get the edition field of the given host.

_Signature:_

```
string get_edition (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;editions

_Overview:_

Get the editions field of the given host.

_Signature:_

```
string set get_editions (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;enabled

_Overview:_

Get the enabled field of the given host.

_Signature:_

```
bool get_enabled (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;external&#95;auth&#95;configuration

_Overview:_

Get the external&#95;auth&#95;configuration field of the given host.

_Signature:_

```
(string -> string) map get_external_auth_configuration (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;external&#95;auth&#95;service&#95;name

_Overview:_

Get the external&#95;auth&#95;service&#95;name field of the given host.

_Signature:_

```
string get_external_auth_service_name (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;external&#95;auth&#95;type

_Overview:_

Get the external&#95;auth&#95;type field of the given host.

_Signature:_

```
string get_external_auth_type (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;features

_Overview:_

Get the features field of the given host.

_Signature:_

```
Feature ref set get_features (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Feature ref set`

value of the field

### RPC name: get&#95;guest&#95;VCPUs&#95;params

_Overview:_

Get the guest&#95;VCPUs&#95;params field of the given host.

_Signature:_

```
(string -> string) map get_guest_VCPUs_params (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;ha&#95;network&#95;peers

_Overview:_

Get the ha&#95;network&#95;peers field of the given host.

_Signature:_

```
string set get_ha_network_peers (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;ha&#95;statefiles

_Overview:_

Get the ha&#95;statefiles field of the given host.

_Signature:_

```
string set get_ha_statefiles (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;host&#95;CPUs

_Overview:_

Get the host&#95;CPUs field of the given host.

_Signature:_

```
host_cpu ref set get_host_CPUs (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_cpu ref set`

value of the field

### RPC name: get&#95;hostname

_Overview:_

Get the hostname field of the given host.

_Signature:_

```
string get_hostname (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;https&#95;only

_Overview:_

Get the https&#95;only field of the given host.

_Signature:_

```
bool get_https_only (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;iscsi&#95;iqn

_Overview:_

Get the iscsi&#95;iqn field of the given host.

_Signature:_

```
string get_iscsi_iqn (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;last&#95;software&#95;update

_Overview:_

Get the last&#95;software&#95;update field of the given host.

_Signature:_

```
datetime get_last_software_update (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: get&#95;last&#95;update&#95;hash

_Overview:_

Get the last&#95;update&#95;hash field of the given host.

_Signature:_

```
string get_last_update_hash (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;latest&#95;synced&#95;updates&#95;applied

_Overview:_

Get the latest&#95;synced&#95;updates&#95;applied field of the given host.

_Signature:_

```
latest_synced_updates_applied_state get_latest_synced_updates_applied (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `latest_synced_updates_applied_state`

value of the field

### RPC name: get&#95;license&#95;params

_Overview:_

Get the license&#95;params field of the given host.

_Signature:_

```
(string -> string) map get_license_params (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;license&#95;server

_Overview:_

Get the license&#95;server field of the given host.

_Signature:_

```
(string -> string) map get_license_server (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;local&#95;cache&#95;sr

_Overview:_

Get the local&#95;cache&#95;sr field of the given host.

_Signature:_

```
SR ref get_local_cache_sr (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

value of the field

### RPC name: get&#95;log

_Overview:_

Get the host's log file

_Signature:_

```
string get_log (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The Host to query                       |

_Minimum Role:_ read-only

_Return Type:_ `string`

The contents of the host's primary log file

### RPC name: get&#95;logging

_Overview:_

Get the logging field of the given host.

_Signature:_

```
(string -> string) map get_logging (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;management&#95;interface

_Overview:_

Returns the management interface for the specified host

_Signature:_

```
PIF ref get_management_interface (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |Which host's management interface is required|

_Minimum Role:_ pool-operator

_Return Type:_ `PIF ref`

The management interface for the host

### RPC name: get&#95;memory&#95;overhead

_Overview:_

Get the memory/overhead field of the given host.

_Signature:_

```
int get_memory_overhead (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;metrics

_Overview:_

Get the metrics field of the given host.

_Signature:_

```
host_metrics ref get_metrics (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_metrics ref`

value of the field

### RPC name: get&#95;multipathing

_Overview:_

Get the multipathing field of the given host.

_Signature:_

```
bool get_multipathing (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given host.

_Signature:_

```
string get_name_description (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given host.

_Signature:_

```
string get_name_label (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;numa&#95;affinity&#95;policy

_Overview:_

Get the numa&#95;affinity&#95;policy field of the given host.

_Signature:_

```
host_numa_affinity_policy get_numa_affinity_policy (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_numa_affinity_policy`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given host.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;patches

**This message is deprecated.**

_Overview:_

Get the patches field of the given host.

_Signature:_

```
host_patch ref set get_patches (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_patch ref set`

value of the field

### RPC name: get&#95;PBDs

_Overview:_

Get the PBDs field of the given host.

_Signature:_

```
PBD ref set get_PBDs (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PBD ref set`

value of the field

### RPC name: get&#95;PCIs

_Overview:_

Get the PCIs field of the given host.

_Signature:_

```
PCI ref set get_PCIs (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PCI ref set`

value of the field

### RPC name: get&#95;pending&#95;guidances

_Overview:_

Get the pending&#95;guidances field of the given host.

_Signature:_

```
update_guidances set get_pending_guidances (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `update_guidances set`

value of the field

### RPC name: get&#95;pending&#95;guidances&#95;full

_Overview:_

Get the pending&#95;guidances&#95;full field of the given host.

_Signature:_

```
update_guidances set get_pending_guidances_full (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `update_guidances set`

value of the field

### RPC name: get&#95;pending&#95;guidances&#95;recommended

_Overview:_

Get the pending&#95;guidances&#95;recommended field of the given host.

_Signature:_

```
update_guidances set get_pending_guidances_recommended (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `update_guidances set`

value of the field

### RPC name: get&#95;PGPUs

_Overview:_

Get the PGPUs field of the given host.

_Signature:_

```
PGPU ref set get_PGPUs (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PGPU ref set`

value of the field

### RPC name: get&#95;PIFs

_Overview:_

Get the PIFs field of the given host.

_Signature:_

```
PIF ref set get_PIFs (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref set`

value of the field

### RPC name: get&#95;power&#95;on&#95;config

_Overview:_

Get the power&#95;on&#95;config field of the given host.

_Signature:_

```
(string -> string) map get_power_on_config (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;power&#95;on&#95;mode

_Overview:_

Get the power&#95;on&#95;mode field of the given host.

_Signature:_

```
string get_power_on_mode (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;PUSBs

_Overview:_

Get the PUSBs field of the given host.

_Signature:_

```
PUSB ref set get_PUSBs (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PUSB ref set`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given host.

_Signature:_

```
host record get_record (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host record`

all fields from the object

### RPC name: get&#95;resident&#95;VMs

_Overview:_

Get the resident&#95;VMs field of the given host.

_Signature:_

```
VM ref set get_resident_VMs (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref set`

value of the field

### RPC name: get&#95;sched&#95;gran

_Overview:_

Gets xen's sched&#45;gran on a host

_Signature:_

```
host_sched_gran get_sched_gran (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |The host                                |

_Return Type:_ `host_sched_gran`

The host's sched&#45;gran

### RPC name: get&#95;sched&#95;policy

_Overview:_

Get the sched&#95;policy field of the given host.

_Signature:_

```
string get_sched_policy (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;server&#95;certificate

_Overview:_

Get the installed server public TLS certificate.

_Signature:_

```
string get_server_certificate (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |

_Minimum Role:_ read-only

_Return Type:_ `string`

The installed server public TLS certificate, in PEM form.

### RPC name: get&#95;server&#95;localtime

_Overview:_

This call queries the host's clock for the current time in the host's local timezone

_Signature:_

```
datetime get_server_localtime (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host whose clock should be queried  |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

The current local time

### RPC name: get&#95;servertime

_Overview:_

This call queries the host's clock for the current time

_Signature:_

```
datetime get_servertime (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host whose clock should be queried  |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

The current time

### RPC name: get&#95;software&#95;version

_Overview:_

Get the software&#95;version field of the given host.

_Signature:_

```
(string -> string) map get_software_version (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;ssl&#95;legacy

**This message is deprecated.**

_Overview:_

Get the ssl&#95;legacy field of the given host.

_Signature:_

```
bool get_ssl_legacy (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;supported&#95;bootloaders

_Overview:_

Get the supported&#95;bootloaders field of the given host.

_Signature:_

```
string set get_supported_bootloaders (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;suspend&#95;image&#95;sr

_Overview:_

Get the suspend&#95;image&#95;sr field of the given host.

_Signature:_

```
SR ref get_suspend_image_sr (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

value of the field

### RPC name: get&#95;system&#95;status&#95;capabilities

_Overview:_

_Signature:_

```
string get_system_status_capabilities (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host to interrogate                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

An XML fragment containing the system status capabilities.

### RPC name: get&#95;tags

_Overview:_

Get the tags field of the given host.

_Signature:_

```
string set get_tags (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;tls&#95;verification&#95;enabled

_Overview:_

Get the tls&#95;verification&#95;enabled field of the given host.

_Signature:_

```
bool get_tls_verification_enabled (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;uefi&#95;certificates

**This message is deprecated.**

_Overview:_

Get the uefi&#95;certificates field of the given host.

_Signature:_

```
string get_uefi_certificates (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;uncooperative&#95;resident&#95;VMs

**This message is deprecated.**

_Overview:_

Return a set of VMs which are not co&#45;operating with the host's memory control system

_Signature:_

```
VM ref set get_uncooperative_resident_VMs (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |The host to query                       |

_Minimum Role:_ read-only

_Return Type:_ `VM ref set`

VMs which are not co&#45;operating

### RPC name: get&#95;updates

_Overview:_

Get the updates field of the given host.

_Signature:_

```
pool_update ref set get_updates (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pool_update ref set`

value of the field

### RPC name: get&#95;updates&#95;requiring&#95;reboot

_Overview:_

Get the updates&#95;requiring&#95;reboot field of the given host.

_Signature:_

```
pool_update ref set get_updates_requiring_reboot (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pool_update ref set`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given host.

_Signature:_

```
string get_uuid (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;virtual&#95;hardware&#95;platform&#95;versions

_Overview:_

Get the virtual&#95;hardware&#95;platform&#95;versions field of the given host.

_Signature:_

```
int set get_virtual_hardware_platform_versions (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int set`

value of the field

### RPC name: get&#95;vms&#95;which&#95;prevent&#95;evacuation

_Overview:_

Return a set of VMs which prevent the host being evacuated, with per&#45;VM error codes

_Signature:_

```
(VM ref -> string set) map get_vms_which_prevent_evacuation (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |The host to query                       |

_Minimum Role:_ read-only

_Return Type:_ `(VM ref -> string set) map`

VMs which block evacuation together with reasons

### RPC name: has&#95;extension

_Overview:_

Return true if the extension is available on the host

_Signature:_

```
bool has_extension (session ref session_ref, host ref host, string name)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |
|`string`                      |`name`                        |The name of the API call                |

_Minimum Role:_ pool-admin

_Return Type:_ `bool`

True if the extension exists, false otherwise

### RPC name: install&#95;server&#95;certificate

_Overview:_

Install the TLS server certificate.

_Signature:_

```
void install_server_certificate (session ref session_ref, host ref host, string certificate, string private_key, string certificate_chain)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |
|`string`                      |`certificate`                 |The server certificate, in PEM form     |
|`string`                      |`private_key`                 |The unencrypted private key used to sign the certificate, in PKCS&#35;8 form|
|`string`                      |`certificate_chain`           |The certificate chain, in PEM form      |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: license&#95;add

_Overview:_

Apply a new license to a host

_Signature:_

```
void license_add (session ref session_ref, host ref host, string contents)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host to upload the license to       |
|`string`                      |`contents`                    |The contents of the license file, base64 encoded|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `LICENSE_PROCESSING_ERROR`

### RPC name: license&#95;apply

**This message is removed.**

_Overview:_

Apply a new license to a host

_Signature:_

```
void license_apply (session ref session_ref, host ref host, string contents)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host to upload the license to       |
|`string`                      |`contents`                    |The contents of the license file, base64 encoded|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `LICENSE_PROCESSING_ERROR`

### RPC name: license&#95;remove

_Overview:_

Remove any license file from the specified host, and switch that host to the unlicensed edition

_Signature:_

```
void license_remove (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host from which any license will be removed|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: list&#95;methods

_Overview:_

List all supported methods

_Signature:_

```
string set list_methods (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `string set`

The name of every supported method.

### RPC name: local&#95;management&#95;reconfigure

_Overview:_

Reconfigure the management network interface. Should only be used if Host.management&#95;reconfigure is impossible because the network configuration is broken.

_Signature:_

```
void local_management_reconfigure (session ref session_ref, string interface)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`interface`                   |name of the interface to use as a management interface|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: management&#95;disable

_Overview:_

Disable the management network interface

_Signature:_

```
void management_disable (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: management&#95;reconfigure

_Overview:_

Reconfigure the management network interface

_Signature:_

```
void management_reconfigure (session ref session_ref, PIF ref pif)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`pif`                         |reference to a PIF object corresponding to the management interface|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: migrate&#95;receive

_Overview:_

Prepare to receive a VM, returning a token which can be passed to VM.migrate.

_Signature:_

```
(string -> string) map migrate_receive (session ref session_ref, host ref host, network ref network, (string -> string) map options)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The target host                         |
|`network ref`                 |`network`                     |The network through which migration traffic should be received.|
|`(string -> string) map`      |`options`                     |Extra configuration operations          |

_Minimum Role:_ vm-power-admin

_Return Type:_ `(string -> string) map`

A value which should be passed to VM.migrate

### RPC name: power&#95;on

_Overview:_

Attempt to power&#45;on the host &#40;if the capability exists&#41;.

_Signature:_

```
void power_on (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The Host to power on                    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: query&#95;data&#95;source

_Overview:_

Query the latest value of the specified data source

_Signature:_

```
float query_data_source (session ref session_ref, host ref host, string data_source)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |
|`string`                      |`data_source`                 |The data source to query                |

_Minimum Role:_ read-only

_Return Type:_ `float`

The latest value, averaged over the last 5 seconds

### RPC name: reboot

_Overview:_

Reboot the host. &#40;This function can only be called if there are no currently running VMs on the host and it is disabled.&#41;

_Signature:_

```
void reboot (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The Host to reboot                      |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: record&#95;data&#95;source

_Overview:_

Start recording the specified data source

_Signature:_

```
void record_data_source (session ref session_ref, host ref host, string data_source)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |
|`string`                      |`data_source`                 |The data source to record               |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: refresh&#95;pack&#95;info

**This message is deprecated.**

_Overview:_

Refresh the list of installed Supplemental Packs.

_Signature:_

```
void refresh_pack_info (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The Host to modify                      |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: refresh&#95;server&#95;certificate

_Overview:_

Replace the internal self&#45;signed host certficate with a new one.

_Signature:_

```
void refresh_server_certificate (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;guest&#95;VCPUs&#95;params

_Overview:_

Remove the given key and its corresponding value from the guest&#95;VCPUs&#95;params field of the given host.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_guest_VCPUs_params (session ref session_ref, host ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;license&#95;server

_Overview:_

Remove the given key and its corresponding value from the license&#95;server field of the given host.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_license_server (session ref session_ref, host ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;logging

_Overview:_

Remove the given key and its corresponding value from the logging field of the given host.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_logging (session ref session_ref, host ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given host.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, host ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: remove&#95;tags

_Overview:_

Remove the given value from the tags field of the given host.  If the value is not in that Set, then do nothing.

_Signature:_

```
void remove_tags (session ref session_ref, host ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`string`                      |`value`                       |Value to remove                         |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

### RPC name: reset&#95;cpu&#95;features

**This message is removed.**

_Overview:_

Remove the feature mask, such that after a reboot all features of the CPU are enabled.

_Signature:_

```
void reset_cpu_features (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: reset&#95;server&#95;certificate

_Overview:_

Delete the current TLS server certificate and replace by a new, self&#45;signed one. This should only be used with extreme care.

_Signature:_

```
void reset_server_certificate (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: restart&#95;agent

_Overview:_

Restarts the agent after a 10 second pause. WARNING: this is a dangerous operation. Any operations in progress will be aborted, and unrecoverable data loss may occur. The caller is responsible for ensuring that there are no operations in progress when this method is called.

_Signature:_

```
void restart_agent (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The Host on which you want to restart the agent|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: retrieve&#95;wlb&#95;evacuate&#95;recommendations

_Overview:_

Retrieves recommended host migrations to perform when evacuating the host from the wlb server. If a VM cannot be migrated from the host the reason is listed instead of a recommendation.

_Signature:_

```
(VM ref -> string set) map retrieve_wlb_evacuate_recommendations (session ref session_ref, host ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |The host to query                       |

_Minimum Role:_ read-only

_Return Type:_ `(VM ref -> string set) map`

VMs and the reasons why they would block evacuation, or their target host recommended by the wlb server

### RPC name: send&#95;debug&#95;keys

_Overview:_

Inject the given string as debugging keys into Xen

_Signature:_

```
void send_debug_keys (session ref session_ref, host ref host, string keys)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |
|`string`                      |`keys`                        |The keys to send                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: set&#95;address

_Overview:_

Set the address field of the given host.

_Signature:_

```
void set_address (session ref session_ref, host ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;cpu&#95;features

**This message is removed.**

_Overview:_

Set the CPU features to be used after a reboot, if the given features string is valid.

_Signature:_

```
void set_cpu_features (session ref session_ref, host ref host, string features)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |
|`string`                      |`features`                    |The features string &#40;32 hexadecimal digits&#41;|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;crash&#95;dump&#95;sr

_Overview:_

Set the crash&#95;dump&#95;sr field of the given host.

_Signature:_

```
void set_crash_dump_sr (session ref session_ref, host ref self, SR ref value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`SR ref`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;display

_Overview:_

Set the display field of the given host.

_Signature:_

```
void set_display (session ref session_ref, host ref self, host_display value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`host_display`                |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;guest&#95;VCPUs&#95;params

_Overview:_

Set the guest&#95;VCPUs&#95;params field of the given host.

_Signature:_

```
void set_guest_VCPUs_params (session ref session_ref, host ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;hostname

_Overview:_

Set the hostname field of the given host.

_Signature:_

```
void set_hostname (session ref session_ref, host ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;hostname&#95;live

_Overview:_

Sets the host name to the specified string.  Both the API and lower&#45;level system hostname are changed immediately.

_Signature:_

```
void set_hostname_live (session ref session_ref, host ref host, string hostname)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host whose host name to set         |
|`string`                      |`hostname`                    |The new host name                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `HOST_NAME_INVALID`

### RPC name: set&#95;https&#95;only

_Overview:_

updates the host firewall to open or close port 80 depending on the value

_Signature:_

```
void set_https_only (session ref session_ref, host ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |The Host                                |
|`bool`                        |`value`                       |true &#45; http port 80 will be blocked, false &#45; http port 80 will be open|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;iscsi&#95;iqn

_Overview:_

Sets the initiator IQN for the host

_Signature:_

```
void set_iscsi_iqn (session ref session_ref, host ref host, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |
|`string`                      |`value`                       |The value to which the IQN should be set|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;license&#95;server

_Overview:_

Set the license&#95;server field of the given host.

_Signature:_

```
void set_license_server (session ref session_ref, host ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;logging

_Overview:_

Set the logging field of the given host.

_Signature:_

```
void set_logging (session ref session_ref, host ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;multipathing

_Overview:_

Specifies whether multipathing is enabled

_Signature:_

```
void set_multipathing (session ref session_ref, host ref host, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |
|`bool`                        |`value`                       |Whether multipathing should be enabled  |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given host.

_Signature:_

```
void set_name_description (session ref session_ref, host ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given host.

_Signature:_

```
void set_name_label (session ref session_ref, host ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;numa&#95;affinity&#95;policy

_Overview:_

Set VM placement NUMA affinity policy

_Signature:_

```
void set_numa_affinity_policy (session ref session_ref, host ref self, host_numa_affinity_policy value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |The host                                |
|`host_numa_affinity_policy`   |`value`                       |The NUMA affinity policy to apply to a host|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given host.

_Signature:_

```
void set_other_config (session ref session_ref, host ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;power&#95;on&#95;mode

_Overview:_

Set the power&#45;on&#45;mode, host, user and password

_Signature:_

```
void set_power_on_mode (session ref session_ref, host ref self, string power_on_mode, (string -> string) map power_on_config)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |The host                                |
|`string`                      |`power_on_mode`               |power&#45;on&#45;mode can be empty, wake&#45;on&#45;lan, DRAC or other|
|`(string -> string) map`      |`power_on_config`             |Power on config                         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;sched&#95;gran

_Overview:_

Sets xen's sched&#45;gran on a host. See: https://xenbits.xen.org/docs/unstable/misc/xen&#45;command&#45;line.html&#35;sched&#45;gran&#45;x86

_Signature:_

```
void set_sched_gran (session ref session_ref, host ref self, host_sched_gran value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |The host                                |
|`host_sched_gran`             |`value`                       |The sched&#45;gran to apply to a host   |

_Return Type:_ `void`

### RPC name: set&#95;ssl&#95;legacy

_Overview:_

Enable/disable SSLv3 for interoperability with older server versions. When this is set to a different value, the host immediately restarts its SSL/TLS listening service; typically this takes less than a second but existing connections to it will be broken. API login sessions will remain valid.

_Signature:_

```
void set_ssl_legacy (session ref session_ref, host ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |The host                                |
|`bool`                        |`value`                       |True to allow SSLv3 and ciphersuites as used in old XenServer versions|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;suspend&#95;image&#95;sr

_Overview:_

Set the suspend&#95;image&#95;sr field of the given host.

_Signature:_

```
void set_suspend_image_sr (session ref session_ref, host ref self, SR ref value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`SR ref`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;tags

_Overview:_

Set the tags field of the given host.

_Signature:_

```
void set_tags (session ref session_ref, host ref self, string set value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`self`                        |reference to the object                 |
|`string set`                  |`value`                       |New value to set                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

### RPC name: set&#95;uefi&#95;certificates

**This message is deprecated.**

_Overview:_

Sets the UEFI certificates on a host

_Signature:_

```
void set_uefi_certificates (session ref session_ref, host ref host, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |
|`string`                      |`value`                       |The certificates to apply to a host     |

_Return Type:_ `void`

### RPC name: shutdown

_Overview:_

Shutdown the host. &#40;This function can only be called if there are no currently running VMs on the host and it is disabled.&#41;

_Signature:_

```
void shutdown (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The Host to shutdown                    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: shutdown&#95;agent

_Overview:_

Shuts the agent down after a 10 second pause. WARNING: this is a dangerous operation. Any operations in progress will be aborted, and unrecoverable data loss may occur. The caller is responsible for ensuring that there are no operations in progress when this method is called.

_Signature:_

```
void shutdown_agent (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: sync&#95;data

_Overview:_

This causes the synchronisation of the non&#45;database data &#40;messages, RRDs and so on&#41; stored on the master to be synchronised with the host

_Signature:_

```
void sync_data (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host to whom the data should be sent|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: syslog&#95;reconfigure

_Overview:_

Re&#45;configure syslog logging

_Signature:_

```
void syslog_reconfigure (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |Tell the host to reread its Host.logging parameters and reconfigure itself accordingly|

_Minimum Role:_ pool-operator

_Return Type:_ `void`
