---
 layout: doc
---

# Class: host&#95;crashdump

Represents a host crash dump

## Fields for class: host&#95;crashdump

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`host`              |`host ref`          |_RO/constructor_|Host the crashdump relates to           |
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`size`              |`int`               |_RO/runtime_   |Size of the crashdump                   |
|`timestamp`         |`datetime`          |_RO/runtime_   |Time the crash happened                 |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: host&#95;crashdump

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given host&#95;crashdump.

_Signature:_

```
void add_to_other_config (session ref session_ref, host_crashdump ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_crashdump ref`          |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: destroy

_Overview:_

Destroy specified host crash dump, removing it from the disk.

_Signature:_

```
void destroy (session ref session_ref, host_crashdump ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_crashdump ref`          |`self`                        |The host crashdump to destroy           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the host&#95;crashdumps known to the system.

_Signature:_

```
host_crashdump ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `host_crashdump ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of host&#95;crashdump references to host&#95;crashdump records for all host&#95;crashdumps known to the system.

_Signature:_

```
(host_crashdump ref -> host_crashdump record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(host_crashdump ref -> host_crashdump record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the host&#95;crashdump instance with the specified UUID.

_Signature:_

```
host_crashdump ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `host_crashdump ref`

reference to the object

### RPC name: get&#95;host

_Overview:_

Get the host field of the given host&#95;crashdump.

_Signature:_

```
host ref get_host (session ref session_ref, host_crashdump ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_crashdump ref`          |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given host&#95;crashdump.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, host_crashdump ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_crashdump ref`          |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given host&#95;crashdump.

_Signature:_

```
host_crashdump record get_record (session ref session_ref, host_crashdump ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_crashdump ref`          |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_crashdump record`

all fields from the object

### RPC name: get&#95;size

_Overview:_

Get the size field of the given host&#95;crashdump.

_Signature:_

```
int get_size (session ref session_ref, host_crashdump ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_crashdump ref`          |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;timestamp

_Overview:_

Get the timestamp field of the given host&#95;crashdump.

_Signature:_

```
datetime get_timestamp (session ref session_ref, host_crashdump ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_crashdump ref`          |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given host&#95;crashdump.

_Signature:_

```
string get_uuid (session ref session_ref, host_crashdump ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_crashdump ref`          |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given host&#95;crashdump.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, host_crashdump ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_crashdump ref`          |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given host&#95;crashdump.

_Signature:_

```
void set_other_config (session ref session_ref, host_crashdump ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_crashdump ref`          |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: upload

_Overview:_

Upload the specified host crash dump to a specified URL

_Signature:_

```
void upload (session ref session_ref, host_crashdump ref self, string url, (string -> string) map options)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_crashdump ref`          |`self`                        |The host crashdump to upload            |
|`string`                      |`url`                         |The URL to upload to                    |
|`(string -> string) map`      |`options`                     |Extra configuration operations          |

_Minimum Role:_ pool-operator

_Return Type:_ `void`
