---
 layout: doc
---

# Class: LVHD

LVHD SR specific operations

## Fields for class: LVHD

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: LVHD

### RPC name: enable&#95;thin&#95;provisioning

_Overview:_

Upgrades an LVHD SR to enable thin&#45;provisioning. Future VDIs created in this SR will be thinly&#45;provisioned, although existing VDIs will be left alone. Note that the SR must be attached to the SRmaster for upgrade to work.

_Signature:_

```
string enable_thin_provisioning (session ref session_ref, host ref host, SR ref SR, int initial_allocation, int allocation_quantum)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The LVHD Host to upgrade to being thin&#45;provisioned.|
|`SR ref`                      |`SR`                          |The LVHD SR to upgrade to being thin&#45;provisioned.|
|`int`                         |`initial_allocation`          |The initial amount of space to allocate to a newly&#45;created VDI in bytes|
|`int`                         |`allocation_quantum`          |The amount of space to allocate to a VDI when it needs to be enlarged in bytes|

_Minimum Role:_ pool-admin

_Return Type:_ `string`

Message from LVHD.enable&#95;thin&#95;provisioning extension

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the LVHD instance with the specified UUID.

_Signature:_

```
LVHD ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `LVHD ref`

reference to the object

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given LVHD.

_Signature:_

```
LVHD record get_record (session ref session_ref, LVHD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`LVHD ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `LVHD record`

all fields from the object

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given LVHD.

_Signature:_

```
string get_uuid (session ref session_ref, LVHD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`LVHD ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field
