---
 layout: doc
---

# Class: Observer

Describes an observer which will control observability activity in the Toolstack

## Fields for class: Observer

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`attributes`        |`(string -> string) map`|_RO/constructor_|Attributes that observer will add to the data they produce|
|`components`        |`string set`        |_RO/constructor_|The list of xenserver components the observer will broadcast. An empty list means all components|
|`enabled`           |`bool`              |_RO/constructor_|This denotes if the observer is enabled. true if it is enabled and false if it is disabled|
|`endpoints`         |`string set`        |_RO/constructor_|The list of endpoints where data is exported to. Each endpoint is a URL or the string 'bugtool' refering to the internal logs|
|`hosts`             |`host ref set`      |_RO/constructor_|The list of hosts the observer is active on. An empty list means all hosts|
|`name_description`  |`string`            |_RW_           |a notes field containing human&#45;readable description|
|`name_label`        |`string`            |_RW_           |a human&#45;readable name               |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: Observer

### RPC name: create

_Overview:_

Create a new Observer instance, and return its handle.

_Signature:_

```
Observer ref create (session ref session_ref, Observer record args)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Observer record`             |`args`                        |All constructor arguments               |

_Minimum Role:_ pool-admin

_Return Type:_ `Observer ref`

reference to the newly created object

### RPC name: destroy

_Overview:_

Destroy the specified Observer instance.

_Signature:_

```
void destroy (session ref session_ref, Observer ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Observer ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the Observers known to the system.

_Signature:_

```
Observer ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `Observer ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of Observer references to Observer records for all Observers known to the system.

_Signature:_

```
(Observer ref -> Observer record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(Observer ref -> Observer record) map`

records of all objects

### RPC name: get&#95;attributes

_Overview:_

Get the attributes field of the given Observer.

_Signature:_

```
(string -> string) map get_attributes (session ref session_ref, Observer ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Observer ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the Observer instances with the given label.

_Signature:_

```
Observer ref set get_by_name_label (session ref session_ref, string label)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`label`                       |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `Observer ref set`

references to objects with matching names

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the Observer instance with the specified UUID.

_Signature:_

```
Observer ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `Observer ref`

reference to the object

### RPC name: get&#95;components

_Overview:_

Get the components field of the given Observer.

_Signature:_

```
string set get_components (session ref session_ref, Observer ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Observer ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;enabled

_Overview:_

Get the enabled field of the given Observer.

_Signature:_

```
bool get_enabled (session ref session_ref, Observer ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Observer ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;endpoints

_Overview:_

Get the endpoints field of the given Observer.

_Signature:_

```
string set get_endpoints (session ref session_ref, Observer ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Observer ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;hosts

_Overview:_

Get the hosts field of the given Observer.

_Signature:_

```
host ref set get_hosts (session ref session_ref, Observer ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Observer ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref set`

value of the field

### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given Observer.

_Signature:_

```
string get_name_description (session ref session_ref, Observer ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Observer ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given Observer.

_Signature:_

```
string get_name_label (session ref session_ref, Observer ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Observer ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given Observer.

_Signature:_

```
Observer record get_record (session ref session_ref, Observer ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Observer ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Observer record`

all fields from the object

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given Observer.

_Signature:_

```
string get_uuid (session ref session_ref, Observer ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Observer ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: set&#95;attributes

_Overview:_

Set the attributes of an observer. These are used to emit metadata by the observer

_Signature:_

```
void set_attributes (session ref session_ref, Observer ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Observer ref`                |`self`                        |The observer                            |
|`(string -> string) map`      |`value`                       |The attributes that the observer emits as part of the data|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: set&#95;components

_Overview:_

Set the components on which the observer will broadcast to. i.e. xapi, xenopsd, networkd, etc.

_Signature:_

```
void set_components (session ref session_ref, Observer ref self, string set value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Observer ref`                |`self`                        |The observer                            |
|`string set`                  |`value`                       |The components the observer will broadcast to|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: set&#95;enabled

_Overview:_

Enable / disable this observer which will stop the observer from producing observability information

_Signature:_

```
void set_enabled (session ref session_ref, Observer ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Observer ref`                |`self`                        |The observer                            |
|`bool`                        |`value`                       |If the observer is to be enabled &#40;true&#41; or disabled &#40;false&#41;|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: set&#95;endpoints

_Overview:_

Set the file/HTTP endpoints the observer sends data to

_Signature:_

```
void set_endpoints (session ref session_ref, Observer ref self, string set value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Observer ref`                |`self`                        |The observer                            |
|`string set`                  |`value`                       |The endpoints that the observer will export data to. A URL or the string 'bugtool'. This can refer to an enpoint to the local file system|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: set&#95;hosts

_Overview:_

Sets the hosts that the observer is to be registered on

_Signature:_

```
void set_hosts (session ref session_ref, Observer ref self, host ref set value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Observer ref`                |`self`                        |The observer                            |
|`host ref set`                |`value`                       |Hosts the observer is registered on     |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given Observer.

_Signature:_

```
void set_name_description (session ref session_ref, Observer ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Observer ref`                |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given Observer.

_Signature:_

```
void set_name_label (session ref session_ref, Observer ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Observer ref`                |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`
