---
 layout: doc
---

# Class: PCI

A PCI device

## Fields for class: PCI

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`class_name`        |`string`            |_RO/constructor_|PCI class name                          |
|`dependencies`      |`PCI ref set`       |_RO/runtime_   |List of dependent PCI devices           |
|`device_name`       |`string`            |_RO/constructor_|Device name                             |
|`driver_name`       |`string`            |_RO/constructor_|Driver name                             |
|`host`              |`host ref`          |_RO/constructor_|Physical machine that owns the PCI device|
|`other_config`      |`(string -> string) map`|_RW_           |Additional configuration                |
|`pci_id`            |`string`            |_RO/constructor_|PCI ID of the physical device           |
|`subsystem_device_name`|`string`            |_RO/constructor_|Subsystem device name                   |
|`subsystem_vendor_name`|`string`            |_RO/constructor_|Subsystem vendor name                   |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`vendor_name`       |`string`            |_RO/constructor_|Vendor name                             |

## RPCs associated with class: PCI

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given PCI.

_Signature:_

```
void add_to_other_config (session ref session_ref, PCI ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PCI ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: disable&#95;dom0&#95;access

_Overview:_

Hide a PCI device from the dom0 kernel. &#40;Takes affect after next boot.&#41;

_Signature:_

```
pci_dom0_access disable_dom0_access (session ref session_ref, PCI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PCI ref`                     |`self`                        |The PCI to hide                         |

_Minimum Role:_ pool-operator

_Return Type:_ `pci_dom0_access`

The accessibility of this PCI from dom0

### RPC name: enable&#95;dom0&#95;access

_Overview:_

Unhide a PCI device from the dom0 kernel. &#40;Takes affect after next boot.&#41;

_Signature:_

```
pci_dom0_access enable_dom0_access (session ref session_ref, PCI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PCI ref`                     |`self`                        |The PCI to unhide                       |

_Minimum Role:_ pool-operator

_Return Type:_ `pci_dom0_access`

The accessibility of this PCI from dom0

### RPC name: get&#95;all

_Overview:_

Return a list of all the PCIs known to the system.

_Signature:_

```
PCI ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `PCI ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PCI references to PCI records for all PCIs known to the system.

_Signature:_

```
(PCI ref -> PCI record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(PCI ref -> PCI record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PCI instance with the specified UUID.

_Signature:_

```
PCI ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PCI ref`

reference to the object

### RPC name: get&#95;class&#95;name

_Overview:_

Get the class&#95;name field of the given PCI.

_Signature:_

```
string get_class_name (session ref session_ref, PCI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PCI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;dependencies

_Overview:_

Get the dependencies field of the given PCI.

_Signature:_

```
PCI ref set get_dependencies (session ref session_ref, PCI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PCI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PCI ref set`

value of the field

### RPC name: get&#95;device&#95;name

_Overview:_

Get the device&#95;name field of the given PCI.

_Signature:_

```
string get_device_name (session ref session_ref, PCI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PCI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;dom0&#95;access&#95;status

_Overview:_

Return a PCI device dom0 access status.

_Signature:_

```
pci_dom0_access get_dom0_access_status (session ref session_ref, PCI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PCI ref`                     |`self`                        |The PCI                                 |

_Minimum Role:_ pool-operator

_Return Type:_ `pci_dom0_access`

The accessibility of this PCI from dom0

### RPC name: get&#95;driver&#95;name

_Overview:_

Get the driver&#95;name field of the given PCI.

_Signature:_

```
string get_driver_name (session ref session_ref, PCI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PCI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;host

_Overview:_

Get the host field of the given PCI.

_Signature:_

```
host ref get_host (session ref session_ref, PCI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PCI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given PCI.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, PCI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PCI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;pci&#95;id

_Overview:_

Get the pci&#95;id field of the given PCI.

_Signature:_

```
string get_pci_id (session ref session_ref, PCI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PCI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PCI.

_Signature:_

```
PCI record get_record (session ref session_ref, PCI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PCI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PCI record`

all fields from the object

### RPC name: get&#95;subsystem&#95;device&#95;name

_Overview:_

Get the subsystem&#95;device&#95;name field of the given PCI.

_Signature:_

```
string get_subsystem_device_name (session ref session_ref, PCI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PCI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;subsystem&#95;vendor&#95;name

_Overview:_

Get the subsystem&#95;vendor&#95;name field of the given PCI.

_Signature:_

```
string get_subsystem_vendor_name (session ref session_ref, PCI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PCI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PCI.

_Signature:_

```
string get_uuid (session ref session_ref, PCI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PCI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;vendor&#95;name

_Overview:_

Get the vendor&#95;name field of the given PCI.

_Signature:_

```
string get_vendor_name (session ref session_ref, PCI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PCI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given PCI.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, PCI ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PCI ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given PCI.

_Signature:_

```
void set_other_config (session ref session_ref, PCI ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PCI ref`                     |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`
