---
 layout: doc
---

# Class: PIF

A physical network interface &#40;note separate VLANs are represented as several PIFs&#41;

## Fields for class: PIF

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`bond_master_of`    |`Bond ref set`      |_RO/runtime_   |Indicates this PIF represents the results of a bond|
|`bond_slave_of`     |`Bond ref`          |_RO/runtime_   |Indicates which bond this interface is part of|
|`capabilities`      |`string set`        |_RO/runtime_   |Additional capabilities on the interface.|
|`currently_attached`|`bool`              |_RO/runtime_   |true if this interface is online        |
|`device`            |`string`            |_RO/constructor_|machine&#45;readable name of the interface &#40;e.g. eth0&#41;|
|`disallow_unplug`   |`bool`              |_RO/runtime_   |Prevent this PIF from being unplugged; set this to notify the management tool&#45;stack that the PIF has a special use and should not be unplugged under any circumstances &#40;e.g. because you're running storage traffic over it&#41;|
|`DNS`               |`string`            |_RO/runtime_   |Comma separated list of the IP addresses of the DNS servers to use|
|`gateway`           |`string`            |_RO/runtime_   |IP gateway                              |
|`host`              |`host ref`          |_RO/constructor_|physical machine to which this pif is connected|
|`igmp_snooping_status`|`pif_igmp_status`   |_RO/runtime_   |The IGMP snooping status of the corresponding network bridge|
|`IP`                |`string`            |_RO/runtime_   |IP address                              |
|`ip_configuration_mode`|`ip_configuration_mode`|_RO/runtime_   |Sets if and how this interface gets an IP address|
|`IPv6`              |`string set`        |_RO/runtime_   |IPv6 address                            |
|`ipv6_configuration_mode`|`ipv6_configuration_mode`|_RO/runtime_   |Sets if and how this interface gets an IPv6 address|
|`ipv6_gateway`      |`string`            |_RO/runtime_   |IPv6 gateway                            |
|`MAC`               |`string`            |_RO/constructor_|ethernet MAC address of physical interface|
|`managed`           |`bool`              |_RO/constructor_|Indicates whether the interface is managed by xapi. If it is not, then xapi will not configure the interface, the commands PIF.plug/unplug/reconfigure&#95;ip&#40;v6&#41; cannot be used, nor can the interface be bonded or have VLANs based on top through xapi.|
|`management`        |`bool`              |_RO/runtime_   |Indicates whether the control software is listening for connections on this interface|
|`metrics`           |`PIF_metrics ref`   |_RO/runtime_   |metrics associated with this PIF        |
|`MTU`               |`int`               |_RO/constructor_|MTU in octets                           |
|`netmask`           |`string`            |_RO/runtime_   |IP netmask                              |
|`network`           |`network ref`       |_RO/constructor_|virtual network to which this pif is connected|
|`other_config`      |`(string -> string) map`|_RW_           |Additional configuration                |
|`PCI`               |`PCI ref`           |_RO/runtime_   |Link to underlying PCI device           |
|`physical`          |`bool`              |_RO/runtime_   |true if this represents a physical network interface|
|`primary_address_type`|`primary_address_type`|_RO/runtime_   |Which protocol should define the primary address of this interface|
|`properties`        |`(string -> string) map`|_RO/runtime_   |Additional configuration properties for the interface.|
|`sriov_logical_PIF_of`|`network_sriov ref set`|_RO/runtime_   |Indicates which network&#95;sriov this interface is logical of|
|`sriov_physical_PIF_of`|`network_sriov ref set`|_RO/runtime_   |Indicates which network&#95;sriov this interface is physical of|
|`tunnel_access_PIF_of`|`tunnel ref set`    |_RO/runtime_   |Indicates to which tunnel this PIF gives access|
|`tunnel_transport_PIF_of`|`tunnel ref set`    |_RO/runtime_   |Indicates to which tunnel this PIF provides transport|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`VLAN`              |`int`               |_RO/constructor_|VLAN tag for all traffic passing through this interface|
|`VLAN_master_of`    |`VLAN ref`          |_RO/runtime_   |Indicates which VLAN this interface receives untagged traffic from|
|`VLAN_slave_of`     |`VLAN ref set`      |_RO/runtime_   |Indicates which VLANs this interface transmits tagged traffic to|

## RPCs associated with class: PIF

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given PIF.

_Signature:_

```
void add_to_other_config (session ref session_ref, PIF ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: create&#95;VLAN

**This message is deprecated.**

_Overview:_

Create a VLAN interface from an existing physical interface. This call is deprecated: use VLAN.create instead

_Signature:_

```
PIF ref create_VLAN (session ref session_ref, string device, network ref network, host ref host, int VLAN)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`device`                      |physical interface on which to create the VLAN interface|
|`network ref`                 |`network`                     |network to which this interface should be connected|
|`host ref`                    |`host`                        |physical machine to which this PIF is connected|
|`int`                         |`VLAN`                        |VLAN tag for the new interface          |

_Minimum Role:_ pool-operator

_Return Type:_ `PIF ref`

The reference of the created PIF object

_Possible Error Codes:_ `VLAN_TAG_INVALID`

### RPC name: db&#95;forget

_Overview:_

Destroy a PIF database record.

_Signature:_

```
void db_forget (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |The ref of the PIF whose database record should be destroyed|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: db&#95;introduce

_Overview:_

Create a new PIF record in the database only

_Signature:_

```
PIF ref db_introduce (session ref session_ref, string device, network ref network, host ref host, string MAC, int MTU, int VLAN, bool physical, ip_configuration_mode ip_configuration_mode, string IP, string netmask, string gateway, string DNS, Bond ref bond_slave_of, VLAN ref VLAN_master_of, bool management, (string -> string) map other_config, bool disallow_unplug, ipv6_configuration_mode ipv6_configuration_mode, string set IPv6, string ipv6_gateway, primary_address_type primary_address_type, bool managed, (string -> string) map properties)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`device`                      |                                        |
|`network ref`                 |`network`                     |                                        |
|`host ref`                    |`host`                        |                                        |
|`string`                      |`MAC`                         |                                        |
|`int`                         |`MTU`                         |                                        |
|`int`                         |`VLAN`                        |                                        |
|`bool`                        |`physical`                    |                                        |
|`ip_configuration_mode`       |`ip_configuration_mode`       |                                        |
|`string`                      |`IP`                          |                                        |
|`string`                      |`netmask`                     |                                        |
|`string`                      |`gateway`                     |                                        |
|`string`                      |`DNS`                         |                                        |
|`Bond ref`                    |`bond_slave_of`               |                                        |
|`VLAN ref`                    |`VLAN_master_of`              |                                        |
|`bool`                        |`management`                  |                                        |
|`(string -> string) map`      |`other_config`                |                                        |
|`bool`                        |`disallow_unplug`             |                                        |
|`ipv6_configuration_mode`     |`ipv6_configuration_mode`     |                                        |
|`string set`                  |`IPv6`                        |                                        |
|`string`                      |`ipv6_gateway`                |                                        |
|`primary_address_type`        |`primary_address_type`        |                                        |
|`bool`                        |`managed`                     |                                        |
|`(string -> string) map`      |`properties`                  |                                        |

_Minimum Role:_ pool-operator

_Return Type:_ `PIF ref`

The ref of the newly created PIF record.

### RPC name: destroy

**This message is deprecated.**

_Overview:_

Destroy the PIF object &#40;provided it is a VLAN interface&#41;. This call is deprecated: use VLAN.destroy or Bond.destroy instead

_Signature:_

```
void destroy (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |the PIF object to destroy               |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `PIF_IS_PHYSICAL`

### RPC name: forget

_Overview:_

Destroy the PIF object matching a particular network interface

_Signature:_

```
void forget (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |The PIF object to destroy               |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `PIF_TUNNEL_STILL_EXISTS`, `CLUSTERING_ENABLED`

### RPC name: get&#95;all

_Overview:_

Return a list of all the PIFs known to the system.

_Signature:_

```
PIF ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PIF references to PIF records for all PIFs known to the system.

_Signature:_

```
(PIF ref -> PIF record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(PIF ref -> PIF record) map`

records of all objects

### RPC name: get&#95;bond&#95;master&#95;of

_Overview:_

Get the bond&#95;master&#95;of field of the given PIF.

_Signature:_

```
Bond ref set get_bond_master_of (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Bond ref set`

value of the field

### RPC name: get&#95;bond&#95;slave&#95;of

_Overview:_

Get the bond&#95;slave&#95;of field of the given PIF.

_Signature:_

```
Bond ref get_bond_slave_of (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Bond ref`

value of the field

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PIF instance with the specified UUID.

_Signature:_

```
PIF ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

reference to the object

### RPC name: get&#95;capabilities

_Overview:_

Get the capabilities field of the given PIF.

_Signature:_

```
string set get_capabilities (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;currently&#95;attached

_Overview:_

Get the currently&#95;attached field of the given PIF.

_Signature:_

```
bool get_currently_attached (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;device

_Overview:_

Get the device field of the given PIF.

_Signature:_

```
string get_device (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;disallow&#95;unplug

_Overview:_

Get the disallow&#95;unplug field of the given PIF.

_Signature:_

```
bool get_disallow_unplug (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;DNS

_Overview:_

Get the DNS field of the given PIF.

_Signature:_

```
string get_DNS (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;gateway

_Overview:_

Get the gateway field of the given PIF.

_Signature:_

```
string get_gateway (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;host

_Overview:_

Get the host field of the given PIF.

_Signature:_

```
host ref get_host (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

### RPC name: get&#95;igmp&#95;snooping&#95;status

_Overview:_

Get the igmp&#95;snooping&#95;status field of the given PIF.

_Signature:_

```
pif_igmp_status get_igmp_snooping_status (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pif_igmp_status`

value of the field

### RPC name: get&#95;IP

_Overview:_

Get the IP field of the given PIF.

_Signature:_

```
string get_IP (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;ip&#95;configuration&#95;mode

_Overview:_

Get the ip&#95;configuration&#95;mode field of the given PIF.

_Signature:_

```
ip_configuration_mode get_ip_configuration_mode (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `ip_configuration_mode`

value of the field

### RPC name: get&#95;IPv6

_Overview:_

Get the IPv6 field of the given PIF.

_Signature:_

```
string set get_IPv6 (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;ipv6&#95;configuration&#95;mode

_Overview:_

Get the ipv6&#95;configuration&#95;mode field of the given PIF.

_Signature:_

```
ipv6_configuration_mode get_ipv6_configuration_mode (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `ipv6_configuration_mode`

value of the field

### RPC name: get&#95;ipv6&#95;gateway

_Overview:_

Get the ipv6&#95;gateway field of the given PIF.

_Signature:_

```
string get_ipv6_gateway (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;MAC

_Overview:_

Get the MAC field of the given PIF.

_Signature:_

```
string get_MAC (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;managed

_Overview:_

Get the managed field of the given PIF.

_Signature:_

```
bool get_managed (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;management

_Overview:_

Get the management field of the given PIF.

_Signature:_

```
bool get_management (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;metrics

_Overview:_

Get the metrics field of the given PIF.

_Signature:_

```
PIF_metrics ref get_metrics (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF_metrics ref`

value of the field

### RPC name: get&#95;MTU

_Overview:_

Get the MTU field of the given PIF.

_Signature:_

```
int get_MTU (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;netmask

_Overview:_

Get the netmask field of the given PIF.

_Signature:_

```
string get_netmask (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;network

_Overview:_

Get the network field of the given PIF.

_Signature:_

```
network ref get_network (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `network ref`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given PIF.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;PCI

_Overview:_

Get the PCI field of the given PIF.

_Signature:_

```
PCI ref get_PCI (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PCI ref`

value of the field

### RPC name: get&#95;physical

_Overview:_

Get the physical field of the given PIF.

_Signature:_

```
bool get_physical (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;primary&#95;address&#95;type

_Overview:_

Get the primary&#95;address&#95;type field of the given PIF.

_Signature:_

```
primary_address_type get_primary_address_type (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `primary_address_type`

value of the field

### RPC name: get&#95;properties

_Overview:_

Get the properties field of the given PIF.

_Signature:_

```
(string -> string) map get_properties (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PIF.

_Signature:_

```
PIF record get_record (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF record`

all fields from the object

### RPC name: get&#95;sriov&#95;logical&#95;PIF&#95;of

_Overview:_

Get the sriov&#95;logical&#95;PIF&#95;of field of the given PIF.

_Signature:_

```
network_sriov ref set get_sriov_logical_PIF_of (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `network_sriov ref set`

value of the field

### RPC name: get&#95;sriov&#95;physical&#95;PIF&#95;of

_Overview:_

Get the sriov&#95;physical&#95;PIF&#95;of field of the given PIF.

_Signature:_

```
network_sriov ref set get_sriov_physical_PIF_of (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `network_sriov ref set`

value of the field

### RPC name: get&#95;tunnel&#95;access&#95;PIF&#95;of

_Overview:_

Get the tunnel&#95;access&#95;PIF&#95;of field of the given PIF.

_Signature:_

```
tunnel ref set get_tunnel_access_PIF_of (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `tunnel ref set`

value of the field

### RPC name: get&#95;tunnel&#95;transport&#95;PIF&#95;of

_Overview:_

Get the tunnel&#95;transport&#95;PIF&#95;of field of the given PIF.

_Signature:_

```
tunnel ref set get_tunnel_transport_PIF_of (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `tunnel ref set`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PIF.

_Signature:_

```
string get_uuid (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;VLAN

_Overview:_

Get the VLAN field of the given PIF.

_Signature:_

```
int get_VLAN (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;VLAN&#95;master&#95;of

_Overview:_

Get the VLAN&#95;master&#95;of field of the given PIF.

_Signature:_

```
VLAN ref get_VLAN_master_of (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VLAN ref`

value of the field

### RPC name: get&#95;VLAN&#95;slave&#95;of

_Overview:_

Get the VLAN&#95;slave&#95;of field of the given PIF.

_Signature:_

```
VLAN ref set get_VLAN_slave_of (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VLAN ref set`

value of the field

### RPC name: introduce

_Overview:_

Create a PIF object matching a particular network interface

_Signature:_

```
PIF ref introduce (session ref session_ref, host ref host, string MAC, string device, bool managed)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host on which the interface exists  |
|`string`                      |`MAC`                         |The MAC address of the interface        |
|`string`                      |`device`                      |The device name to use for the interface|
|`bool`                        |`managed`                     |Indicates whether the interface is managed by xapi &#40;defaults to "true"&#41;|

_Minimum Role:_ pool-operator

_Return Type:_ `PIF ref`

The reference of the created PIF object

### RPC name: plug

_Overview:_

Attempt to bring up a physical interface

_Signature:_

```
void plug (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |the PIF object to plug                  |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `TRANSPORT_PIF_NOT_CONFIGURED`

### RPC name: reconfigure&#95;ip

_Overview:_

Reconfigure the IP address settings for this interface

_Signature:_

```
void reconfigure_ip (session ref session_ref, PIF ref self, ip_configuration_mode mode, string IP, string netmask, string gateway, string DNS)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |the PIF object to reconfigure           |
|`ip_configuration_mode`       |`mode`                        |whether to use dynamic/static/no&#45;assignment|
|`string`                      |`IP`                          |the new IP address                      |
|`string`                      |`netmask`                     |the new netmask                         |
|`string`                      |`gateway`                     |the new gateway                         |
|`string`                      |`DNS`                         |the new DNS settings                    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `CLUSTERING_ENABLED`

### RPC name: reconfigure&#95;ipv6

_Overview:_

Reconfigure the IPv6 address settings for this interface

_Signature:_

```
void reconfigure_ipv6 (session ref session_ref, PIF ref self, ipv6_configuration_mode mode, string IPv6, string gateway, string DNS)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |the PIF object to reconfigure           |
|`ipv6_configuration_mode`     |`mode`                        |whether to use dynamic/static/no&#45;assignment|
|`string`                      |`IPv6`                        |the new IPv6 address &#40;in &lt;addr&gt;/&lt;prefix length&gt; format&#41;|
|`string`                      |`gateway`                     |the new gateway                         |
|`string`                      |`DNS`                         |the new DNS settings                    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `CLUSTERING_ENABLED`

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given PIF.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, PIF ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: scan

_Overview:_

Scan for physical interfaces on a host and create PIF objects to represent them

_Signature:_

```
void scan (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host on which to scan               |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;disallow&#95;unplug

_Overview:_

Set whether unplugging the PIF is allowed

_Signature:_

```
void set_disallow_unplug (session ref session_ref, PIF ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |Reference to the object                 |
|`bool`                        |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `OTHER_OPERATION_IN_PROGRESS`, `CLUSTERING_ENABLED`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given PIF.

_Signature:_

```
void set_other_config (session ref session_ref, PIF ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;primary&#95;address&#95;type

_Overview:_

Change the primary address type used by this PIF

_Signature:_

```
void set_primary_address_type (session ref session_ref, PIF ref self, primary_address_type primary_address_type)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |the PIF object to reconfigure           |
|`primary_address_type`        |`primary_address_type`        |Whether to prefer IPv4 or IPv6 connections|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;property

_Overview:_

Set the value of a property of the PIF

_Signature:_

```
void set_property (session ref session_ref, PIF ref self, string name, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |The PIF                                 |
|`string`                      |`name`                        |The property name                       |
|`string`                      |`value`                       |The property value                      |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: unplug

_Overview:_

Attempt to bring down a physical interface

_Signature:_

```
void unplug (session ref session_ref, PIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`self`                        |the PIF object to unplug                |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `HA_OPERATION_WOULD_BREAK_FAILOVER_PLAN`, `VIF_IN_USE`, `PIF_DOES_NOT_ALLOW_UNPLUG`, `PIF_HAS_FCOE_SR_IN_USE`
