---
 layout: doc
---

# Class: PVS&#95;server

individual machine serving provisioning &#40;block&#41; data

## Fields for class: PVS&#95;server

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`addresses`         |`string set`        |_RO/constructor_|IPv4 addresses of this server           |
|`first_port`        |`int`               |_RO/constructor_|First UDP port accepted by this server  |
|`last_port`         |`int`               |_RO/constructor_|Last UDP port accepted by this server   |
|`site`              |`PVS_site ref`      |_RO/constructor_|PVS site this server is part of         |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: PVS&#95;server

### RPC name: forget

_Overview:_

forget a PVS server

_Signature:_

```
void forget (session ref session_ref, PVS_server ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_server ref`              |`self`                        |this PVS server                         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;addresses

_Overview:_

Get the addresses field of the given PVS&#95;server.

_Signature:_

```
string set get_addresses (session ref session_ref, PVS_server ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_server ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;all

_Overview:_

Return a list of all the PVS&#95;servers known to the system.

_Signature:_

```
PVS_server ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `PVS_server ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PVS&#95;server references to PVS&#95;server records for all PVS&#95;servers known to the system.

_Signature:_

```
(PVS_server ref -> PVS_server record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(PVS_server ref -> PVS_server record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PVS&#95;server instance with the specified UUID.

_Signature:_

```
PVS_server ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PVS_server ref`

reference to the object

### RPC name: get&#95;first&#95;port

_Overview:_

Get the first&#95;port field of the given PVS&#95;server.

_Signature:_

```
int get_first_port (session ref session_ref, PVS_server ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_server ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;last&#95;port

_Overview:_

Get the last&#95;port field of the given PVS&#95;server.

_Signature:_

```
int get_last_port (session ref session_ref, PVS_server ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_server ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PVS&#95;server.

_Signature:_

```
PVS_server record get_record (session ref session_ref, PVS_server ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_server ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_server record`

all fields from the object

### RPC name: get&#95;site

_Overview:_

Get the site field of the given PVS&#95;server.

_Signature:_

```
PVS_site ref get_site (session ref session_ref, PVS_server ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_server ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_site ref`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PVS&#95;server.

_Signature:_

```
string get_uuid (session ref session_ref, PVS_server ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_server ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: introduce

_Overview:_

introduce new PVS server

_Signature:_

```
PVS_server ref introduce (session ref session_ref, string set addresses, int first_port, int last_port, PVS_site ref site)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string set`                  |`addresses`                   |IPv4/IPv6 addresses of the server       |
|`int`                         |`first_port`                  |first UDP port accepted by this server  |
|`int`                         |`last_port`                   |last UDP port accepted by this server   |
|`PVS_site ref`                |`site`                        |PVS site this server is a part of       |

_Minimum Role:_ pool-operator

_Return Type:_ `PVS_server ref`

the new PVS server
