---
 layout: doc
---

# Class: PVS&#95;site

machines serving blocks of data for provisioning VMs

## Fields for class: PVS&#95;site

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`cache_storage`     |`PVS_cache_storage ref set`|_RO/runtime_   |The SR used by PVS proxy for the cache  |
|`name_description`  |`string`            |_RW_           |a notes field containing human&#45;readable description|
|`name_label`        |`string`            |_RW_           |a human&#45;readable name               |
|`proxies`           |`PVS_proxy ref set` |_RO/runtime_   |The set of proxies associated with the site|
|`PVS_uuid`          |`string`            |_RO/constructor_|Unique identifier of the PVS site, as configured in PVS|
|`servers`           |`PVS_server ref set`|_RO/runtime_   |The set of PVS servers in the site      |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: PVS&#95;site

### RPC name: forget

_Overview:_

Remove a site's meta data

_Signature:_

```
void forget (session ref session_ref, PVS_site ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_site ref`                |`self`                        |this PVS site                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `PVS_SITE_CONTAINS_RUNNING_PROXIES`, `PVS_SITE_CONTAINS_SERVERS`

### RPC name: get&#95;all

_Overview:_

Return a list of all the PVS&#95;sites known to the system.

_Signature:_

```
PVS_site ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `PVS_site ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PVS&#95;site references to PVS&#95;site records for all PVS&#95;sites known to the system.

_Signature:_

```
(PVS_site ref -> PVS_site record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(PVS_site ref -> PVS_site record) map`

records of all objects

### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the PVS&#95;site instances with the given label.

_Signature:_

```
PVS_site ref set get_by_name_label (session ref session_ref, string label)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`label`                       |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `PVS_site ref set`

references to objects with matching names

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PVS&#95;site instance with the specified UUID.

_Signature:_

```
PVS_site ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PVS_site ref`

reference to the object

### RPC name: get&#95;cache&#95;storage

_Overview:_

Get the cache&#95;storage field of the given PVS&#95;site.

_Signature:_

```
PVS_cache_storage ref set get_cache_storage (session ref session_ref, PVS_site ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_site ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_cache_storage ref set`

value of the field

### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given PVS&#95;site.

_Signature:_

```
string get_name_description (session ref session_ref, PVS_site ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_site ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given PVS&#95;site.

_Signature:_

```
string get_name_label (session ref session_ref, PVS_site ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_site ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;proxies

_Overview:_

Get the proxies field of the given PVS&#95;site.

_Signature:_

```
PVS_proxy ref set get_proxies (session ref session_ref, PVS_site ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_site ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_proxy ref set`

value of the field

### RPC name: get&#95;PVS&#95;uuid

_Overview:_

Get the PVS&#95;uuid field of the given PVS&#95;site.

_Signature:_

```
string get_PVS_uuid (session ref session_ref, PVS_site ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_site ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PVS&#95;site.

_Signature:_

```
PVS_site record get_record (session ref session_ref, PVS_site ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_site ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_site record`

all fields from the object

### RPC name: get&#95;servers

_Overview:_

Get the servers field of the given PVS&#95;site.

_Signature:_

```
PVS_server ref set get_servers (session ref session_ref, PVS_site ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_site ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_server ref set`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PVS&#95;site.

_Signature:_

```
string get_uuid (session ref session_ref, PVS_site ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_site ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: introduce

_Overview:_

Introduce new PVS site

_Signature:_

```
PVS_site ref introduce (session ref session_ref, string name_label, string name_description, string PVS_uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`name_label`                  |name of the PVS site                    |
|`string`                      |`name_description`            |description of the PVS site             |
|`string`                      |`PVS_uuid`                    |unique identifier of the PVS site       |

_Minimum Role:_ pool-operator

_Return Type:_ `PVS_site ref`

the new PVS site

### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given PVS&#95;site.

_Signature:_

```
void set_name_description (session ref session_ref, PVS_site ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_site ref`                |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given PVS&#95;site.

_Signature:_

```
void set_name_label (session ref session_ref, PVS_site ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_site ref`                |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;PVS&#95;uuid

_Overview:_

Update the PVS UUID of the PVS site

_Signature:_

```
void set_PVS_uuid (session ref session_ref, PVS_site ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_site ref`                |`self`                        |this PVS site                           |
|`string`                      |`value`                       |PVS UUID to be used                     |

_Minimum Role:_ pool-operator

_Return Type:_ `void`
