---
 layout: doc
---

# Class: SDN&#95;controller

Describes the SDN controller that is to connect with the pool

## Fields for class: SDN&#95;controller

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`address`           |`string`            |_RO/constructor_|IP address of the controller            |
|`port`              |`int`               |_RO/constructor_|TCP port of the controller              |
|`protocol`          |`sdn_controller_protocol`|_RO/constructor_|Protocol to connect with SDN controller |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: SDN&#95;controller

### RPC name: forget

_Overview:_

Remove the OVS manager of the pool and destroy the db record.

_Signature:_

```
void forget (session ref session_ref, SDN_controller ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SDN_controller ref`          |`self`                        |this SDN controller                     |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;address

_Overview:_

Get the address field of the given SDN&#95;controller.

_Signature:_

```
string get_address (session ref session_ref, SDN_controller ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SDN_controller ref`          |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;all

_Overview:_

Return a list of all the SDN&#95;controllers known to the system.

_Signature:_

```
SDN_controller ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `SDN_controller ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of SDN&#95;controller references to SDN&#95;controller records for all SDN&#95;controllers known to the system.

_Signature:_

```
(SDN_controller ref -> SDN_controller record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(SDN_controller ref -> SDN_controller record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the SDN&#95;controller instance with the specified UUID.

_Signature:_

```
SDN_controller ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `SDN_controller ref`

reference to the object

### RPC name: get&#95;port

_Overview:_

Get the port field of the given SDN&#95;controller.

_Signature:_

```
int get_port (session ref session_ref, SDN_controller ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SDN_controller ref`          |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;protocol

_Overview:_

Get the protocol field of the given SDN&#95;controller.

_Signature:_

```
sdn_controller_protocol get_protocol (session ref session_ref, SDN_controller ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SDN_controller ref`          |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `sdn_controller_protocol`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given SDN&#95;controller.

_Signature:_

```
SDN_controller record get_record (session ref session_ref, SDN_controller ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SDN_controller ref`          |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SDN_controller record`

all fields from the object

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given SDN&#95;controller.

_Signature:_

```
string get_uuid (session ref session_ref, SDN_controller ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SDN_controller ref`          |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: introduce

_Overview:_

Introduce an SDN controller to the pool.

_Signature:_

```
SDN_controller ref introduce (session ref session_ref, sdn_controller_protocol protocol, string address, int port)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`sdn_controller_protocol`     |`protocol`                    |Protocol to connect with the controller.|
|`string`                      |`address`                     |IP address of the controller.           |
|`int`                         |`port`                        |TCP port of the controller.             |

_Minimum Role:_ pool-operator

_Return Type:_ `SDN_controller ref`

the introduced SDN controller
