---
 layout: doc
---

# Class: secret

A secret

## Fields for class: secret

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`other_config`      |`(string -> string) map`|_RW_           |other&#95;config                        |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`value`             |`string`            |_RW_           |the secret                              |

## RPCs associated with class: secret

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given secret.

_Signature:_

```
void add_to_other_config (session ref session_ref, secret ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`secret ref`                  |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: create

_Overview:_

Create a new secret instance, and return its handle.

_Signature:_

```
secret ref create (session ref session_ref, secret record args)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`secret record`               |`args`                        |All constructor arguments               |

_Minimum Role:_ pool-operator

_Return Type:_ `secret ref`

reference to the newly created object

### RPC name: destroy

_Overview:_

Destroy the specified secret instance.

_Signature:_

```
void destroy (session ref session_ref, secret ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`secret ref`                  |`self`                        |reference to the object                 |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the secrets known to the system.

_Signature:_

```
secret ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ pool-operator

_Return Type:_ `secret ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of secret references to secret records for all secrets known to the system.

_Signature:_

```
(secret ref -> secret record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ pool-operator

_Return Type:_ `(secret ref -> secret record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the secret instance with the specified UUID.

_Signature:_

```
secret ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ pool-operator

_Return Type:_ `secret ref`

reference to the object

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given secret.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, secret ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`secret ref`                  |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given secret.

_Signature:_

```
secret record get_record (session ref session_ref, secret ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`secret ref`                  |`self`                        |reference to the object                 |

_Minimum Role:_ pool-operator

_Return Type:_ `secret record`

all fields from the object

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given secret.

_Signature:_

```
string get_uuid (session ref session_ref, secret ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`secret ref`                  |`self`                        |reference to the object                 |

_Minimum Role:_ pool-operator

_Return Type:_ `string`

value of the field

### RPC name: get&#95;value

_Overview:_

Get the value field of the given secret.

_Signature:_

```
string get_value (session ref session_ref, secret ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`secret ref`                  |`self`                        |reference to the object                 |

_Minimum Role:_ pool-operator

_Return Type:_ `string`

value of the field

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given secret.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, secret ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`secret ref`                  |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given secret.

_Signature:_

```
void set_other_config (session ref session_ref, secret ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`secret ref`                  |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;value

_Overview:_

Set the value field of the given secret.

_Signature:_

```
void set_value (session ref session_ref, secret ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`secret ref`                  |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`
