---
 layout: doc
---

# Class: subject

A user or group that can log in xapi

## Fields for class: subject

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`other_config`      |`(string -> string) map`|_RO/constructor_|additional configuration                |
|`roles`             |`role ref set`      |_RO/runtime_   |the roles associated with this subject  |
|`subject_identifier`|`string`            |_RO/constructor_|the subject identifier, unique in the external directory service|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: subject

### RPC name: add&#95;to&#95;roles

_Overview:_

This call adds a new role to a subject

_Signature:_

```
void add_to_roles (session ref session_ref, subject ref self, role ref role)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`subject ref`                 |`self`                        |The subject who we want to add the role to|
|`role ref`                    |`role`                        |The unique role reference               |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: create

_Overview:_

Create a new subject instance, and return its handle.

_Signature:_

```
subject ref create (session ref session_ref, subject record args)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`subject record`              |`args`                        |All constructor arguments               |

_Minimum Role:_ pool-admin

_Return Type:_ `subject ref`

reference to the newly created object

### RPC name: destroy

_Overview:_

Destroy the specified subject instance.

_Signature:_

```
void destroy (session ref session_ref, subject ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`subject ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the subjects known to the system.

_Signature:_

```
subject ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `subject ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of subject references to subject records for all subjects known to the system.

_Signature:_

```
(subject ref -> subject record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(subject ref -> subject record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the subject instance with the specified UUID.

_Signature:_

```
subject ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `subject ref`

reference to the object

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given subject.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, subject ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`subject ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;permissions&#95;name&#95;label

_Overview:_

This call returns a list of permission names given a subject

_Signature:_

```
string set get_permissions_name_label (session ref session_ref, subject ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`subject ref`                 |`self`                        |The subject whose permissions will be retrieved|

_Minimum Role:_ read-only

_Return Type:_ `string set`

a list of permission names

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given subject.

_Signature:_

```
subject record get_record (session ref session_ref, subject ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`subject ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `subject record`

all fields from the object

### RPC name: get&#95;roles

_Overview:_

Get the roles field of the given subject.

_Signature:_

```
role ref set get_roles (session ref session_ref, subject ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`subject ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `role ref set`

value of the field

### RPC name: get&#95;subject&#95;identifier

_Overview:_

Get the subject&#95;identifier field of the given subject.

_Signature:_

```
string get_subject_identifier (session ref session_ref, subject ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`subject ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given subject.

_Signature:_

```
string get_uuid (session ref session_ref, subject ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`subject ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: remove&#95;from&#95;roles

_Overview:_

This call removes a role from a subject

_Signature:_

```
void remove_from_roles (session ref session_ref, subject ref self, role ref role)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`subject ref`                 |`self`                        |The subject from whom we want to remove the role|
|`role ref`                    |`role`                        |The unique role reference in the subject's roles field|

_Minimum Role:_ pool-admin

_Return Type:_ `void`
