---
 layout: doc
---

# Class: task

A long&#45;running asynchronous task

## Fields for class: task

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`allowed_operations`|`task_allowed_operations set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|`backtrace`         |`string`            |_RO/runtime_   |Function call trace for debugging.      |
|`created`           |`datetime`          |_RO/runtime_   |Time task was created                   |
|`current_operations`|`(string -> task_allowed_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|`error_info`        |`string set`        |_RO/runtime_   |if the task has failed, this field contains the set of associated error strings. Undefined otherwise.|
|`finished`          |`datetime`          |_RO/runtime_   |Time task finished &#40;i.e. succeeded or failed&#41;. If task&#45;status is pending, then the value of this field has no meaning|
|`name_description`  |`string`            |_RO/runtime_   |a notes field containing human&#45;readable description|
|`name_label`        |`string`            |_RO/runtime_   |a human&#45;readable name               |
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`progress`          |`float`             |_RO/runtime_   |This field contains the estimated fraction of the task which is complete. This field should not be used to determine whether the task is complete &#45; for this the status field of the task should be used.|
|`resident_on`       |`host ref`          |_RO/runtime_   |the host on which the task is running   |
|`result`            |`string`            |_RO/runtime_   |if the task has completed successfully, this field contains the result value &#40;either Void or an object reference&#41;. Undefined otherwise.|
|`status`            |`task_status_type`  |_RO/runtime_   |current status of the task              |
|`subtask_of`        |`task ref`          |_RO/runtime_   |Ref pointing to the task this is a substask of.|
|`subtasks`          |`task ref set`      |_RO/runtime_   |List pointing to all the substasks.     |
|`type`              |`string`            |_RO/runtime_   |if the task has completed successfully, this field contains the type of the encoded result &#40;i.e. name of the class whose reference is in the result field&#41;. Undefined otherwise.|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: task

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given task.

_Signature:_

```
void add_to_other_config (session ref session_ref, task ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: cancel

_Overview:_

Request that a task be cancelled. Note that a task may fail to be cancelled and may complete or fail normally and note that, even when a task does cancel, it might take an arbitrary amount of time.

_Signature:_

```
void cancel (session ref session_ref, task ref task)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`task`                        |The task                                |

_Minimum Role:_ read-only

_Return Type:_ `void`

_Possible Error Codes:_ `OPERATION_NOT_ALLOWED`

### RPC name: create

_Overview:_

Create a new task object which must be manually destroyed.

_Signature:_

```
task ref create (session ref session_ref, string label, string description)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`label`                       |short label for the new task            |
|`string`                      |`description`                 |longer description for the new task     |

_Minimum Role:_ read-only

_Return Type:_ `task ref`

The reference of the created task object

### RPC name: destroy

_Overview:_

Destroy the task object

_Signature:_

```
void destroy (session ref session_ref, task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |Reference to the task object            |

_Minimum Role:_ read-only

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the tasks known to the system.

_Signature:_

```
task ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `task ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of task references to task records for all tasks known to the system.

_Signature:_

```
(task ref -> task record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(task ref -> task record) map`

records of all objects

### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given task.

_Signature:_

```
task_allowed_operations set get_allowed_operations (session ref session_ref, task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `task_allowed_operations set`

value of the field

### RPC name: get&#95;backtrace

_Overview:_

Get the backtrace field of the given task.

_Signature:_

```
string get_backtrace (session ref session_ref, task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the task instances with the given label.

_Signature:_

```
task ref set get_by_name_label (session ref session_ref, string label)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`label`                       |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `task ref set`

references to objects with matching names

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the task instance with the specified UUID.

_Signature:_

```
task ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `task ref`

reference to the object

### RPC name: get&#95;created

_Overview:_

Get the created field of the given task.

_Signature:_

```
datetime get_created (session ref session_ref, task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given task.

_Signature:_

```
(string -> task_allowed_operations) map get_current_operations (session ref session_ref, task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> task_allowed_operations) map`

value of the field

### RPC name: get&#95;error&#95;info

_Overview:_

Get the error&#95;info field of the given task.

_Signature:_

```
string set get_error_info (session ref session_ref, task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;finished

_Overview:_

Get the finished field of the given task.

_Signature:_

```
datetime get_finished (session ref session_ref, task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given task.

_Signature:_

```
string get_name_description (session ref session_ref, task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given task.

_Signature:_

```
string get_name_label (session ref session_ref, task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given task.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;progress

_Overview:_

Get the progress field of the given task.

_Signature:_

```
float get_progress (session ref session_ref, task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `float`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given task.

_Signature:_

```
task record get_record (session ref session_ref, task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `task record`

all fields from the object

### RPC name: get&#95;resident&#95;on

_Overview:_

Get the resident&#95;on field of the given task.

_Signature:_

```
host ref get_resident_on (session ref session_ref, task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

### RPC name: get&#95;result

_Overview:_

Get the result field of the given task.

_Signature:_

```
string get_result (session ref session_ref, task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;status

_Overview:_

Get the status field of the given task.

_Signature:_

```
task_status_type get_status (session ref session_ref, task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `task_status_type`

value of the field

### RPC name: get&#95;subtask&#95;of

_Overview:_

Get the subtask&#95;of field of the given task.

_Signature:_

```
task ref get_subtask_of (session ref session_ref, task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `task ref`

value of the field

### RPC name: get&#95;subtasks

_Overview:_

Get the subtasks field of the given task.

_Signature:_

```
task ref set get_subtasks (session ref session_ref, task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `task ref set`

value of the field

### RPC name: get&#95;type

_Overview:_

Get the type field of the given task.

_Signature:_

```
string get_type (session ref session_ref, task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given task.

_Signature:_

```
string get_uuid (session ref session_ref, task ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given task.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, task ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;error&#95;info

_Overview:_

Set the task error info

_Signature:_

```
void set_error_info (session ref session_ref, task ref self, string set value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |Reference to the task object            |
|`string set`                  |`value`                       |Task error info to be set               |

_Minimum Role:_ read-only

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given task.

_Signature:_

```
void set_other_config (session ref session_ref, task ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;progress

_Overview:_

Set the task progress

_Signature:_

```
void set_progress (session ref session_ref, task ref self, float value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |Reference to the task object            |
|`float`                       |`value`                       |Task progress value to be set           |

_Minimum Role:_ read-only

_Return Type:_ `void`

### RPC name: set&#95;result

_Overview:_

Set the task result

_Signature:_

```
void set_result (session ref session_ref, task ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |Reference to the task object            |
|`string`                      |`value`                       |Task result to be set                   |

_Minimum Role:_ read-only

_Return Type:_ `void`

### RPC name: set&#95;status

_Overview:_

Set the task status

_Signature:_

```
void set_status (session ref session_ref, task ref self, task_status_type value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`task ref`                    |`self`                        |Reference to the task object            |
|`task_status_type`            |`value`                       |task status value to be set             |

_Minimum Role:_ read-only

_Return Type:_ `void`
