---
 layout: doc
---

# Class: VDI

A virtual disk image

## Fields for class: VDI

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`allow_caching`     |`bool`              |_RO/runtime_   |true if this VDI is to be cached in the local cache SR|
|`allowed_operations`|`vdi_operations set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|`cbt_enabled`       |`bool`              |_RO/runtime_   |True if changed blocks are tracked for this VDI|
|`crash_dumps`       |`crashdump ref set` |_RO/runtime_   |list of crash dumps that refer to this disk|
|`current_operations`|`(string -> vdi_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|`is_a_snapshot`     |`bool`              |_RO/runtime_   |true if this is a snapshot.             |
|`is_tools_iso`      |`bool`              |_RO/runtime_   |Whether this VDI is a Tools ISO         |
|`location`          |`string`            |_RO/runtime_   |location information                    |
|`managed`           |`bool`              |_RO/runtime_   |                                        |
|`metadata_latest`   |`bool`              |_RO/runtime_   |Whether this VDI contains the latest known accessible metadata for the pool|
|`metadata_of_pool`  |`pool ref`          |_RO/runtime_   |The pool whose metadata is contained in this VDI|
|`missing`           |`bool`              |_RO/runtime_   |true if SR scan operation reported this VDI as not present on disk|
|`name_description`  |`string`            |_RO/constructor_|a notes field containing human&#45;readable description|
|`name_label`        |`string`            |_RO/constructor_|a human&#45;readable name               |
|`on_boot`           |`on_boot`           |_RO/runtime_   |The behaviour of this VDI on a VM boot  |
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`parent`            |`VDI ref`           |_RO/runtime_   |**Deprecated.** This field is always null. Deprecated   |
|`physical_utilisation`|`int`               |_RO/runtime_   |amount of physical space that the disk image is currently taking up on the storage repository &#40;in bytes&#41;|
|`read_only`         |`bool`              |_RO/constructor_|true if this disk may ONLY be mounted read&#45;only|
|`sharable`          |`bool`              |_RO/constructor_|true if this disk may be shared         |
|`sm_config`         |`(string -> string) map`|_RW_           |SM dependent data                       |
|`snapshot_of`       |`VDI ref`           |_RO/runtime_   |Ref pointing to the VDI this snapshot is of.|
|`snapshot_time`     |`datetime`          |_RO/runtime_   |Date/time when this snapshot was created.|
|`snapshots`         |`VDI ref set`       |_RO/runtime_   |List pointing to all the VDIs snapshots.|
|`SR`                |`SR ref`            |_RO/constructor_|storage repository in which the VDI resides|
|`storage_lock`      |`bool`              |_RO/runtime_   |true if this disk is locked at the storage level|
|`tags`              |`string set`        |_RW_           |user&#45;specified tags for categorization purposes|
|`type`              |`vdi_type`          |_RO/constructor_|type of the VDI                         |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`VBDs`              |`VBD ref set`       |_RO/runtime_   |list of vbds that refer to this disk    |
|`virtual_size`      |`int`               |_RO/constructor_|size of disk as presented to the guest &#40;in bytes&#41;. Note that, depending on storage backend type, requested size may not be respected exactly|
|`xenstore_data`     |`(string -> string) map`|_RW_           |data to be inserted into the xenstore tree &#40;/local/domain/0/backend/vbd/&lt;domid&gt;/&lt;device&#45;id&gt;/sm&#45;data&#41; after the VDI is attached. This is generally set by the SM backends on vdi&#95;attach.|

## RPCs associated with class: VDI

### RPC name: add&#95;tags

_Overview:_

Add the given value to the tags field of the given VDI.  If the value is already in that Set, then do nothing.

_Signature:_

```
void add_tags (session ref session_ref, VDI ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to add                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given VDI.

_Signature:_

```
void add_to_other_config (session ref session_ref, VDI ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: add&#95;to&#95;sm&#95;config

_Overview:_

Add the given key&#45;value pair to the sm&#95;config field of the given VDI.

_Signature:_

```
void add_to_sm_config (session ref session_ref, VDI ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: add&#95;to&#95;xenstore&#95;data

_Overview:_

Add the given key&#45;value pair to the xenstore&#95;data field of the given VDI.

_Signature:_

```
void add_to_xenstore_data (session ref session_ref, VDI ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: clone

_Overview:_

Take an exact copy of the VDI and return a reference to the new disk. If any driver&#95;params are specified then these are passed through to the storage&#45;specific substrate driver that implements the clone operation. NB the clone lives in the same Storage Repository as its parent.

_Signature:_

```
VDI ref clone (session ref session_ref, VDI ref vdi, (string -> string) map driver_params)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`vdi`                         |The VDI to clone                        |
|`(string -> string) map`      |`driver_params`               |Optional parameters that are passed through to the backend driver in order to specify storage&#45;type&#45;specific clone options|

_Minimum Role:_ vm-admin

_Return Type:_ `VDI ref`

The ID of the newly created VDI.

### RPC name: copy

_Overview:_

Copy either a full VDI or the block differences between two VDIs into either a fresh VDI or an existing VDI.

_Signature:_

```
VDI ref copy (session ref session_ref, VDI ref vdi, SR ref sr, VDI ref base_vdi, VDI ref into_vdi)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`vdi`                         |The VDI to copy                         |
|`SR ref`                      |`sr`                          |The destination SR &#40;only required if the destination VDI is not specified|
|`VDI ref`                     |`base_vdi`                    |The base VDI &#40;only required if copying only changed blocks, by default all blocks will be copied&#41;|
|`VDI ref`                     |`into_vdi`                    |The destination VDI to copy blocks into &#40;if omitted then a destination SR must be provided and a fresh VDI will be created&#41;|

_Minimum Role:_ vm-admin

_Return Type:_ `VDI ref`

The reference of the VDI where the blocks were written.

_Possible Error Codes:_ `VDI_READONLY`, `VDI_TOO_SMALL`, `VDI_NOT_SPARSE`

### RPC name: create

_Overview:_

Create a new VDI instance, and return its handle.

_Signature:_

```
VDI ref create (session ref session_ref, VDI record args)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI record`                  |`args`                        |All constructor arguments               |

_Minimum Role:_ vm-admin

_Return Type:_ `VDI ref`

reference to the newly created object

### RPC name: data&#95;destroy

_Overview:_

Delete the data of the snapshot VDI, but keep its changed block tracking metadata. When successful, this call changes the type of the VDI to cbt&#95;metadata. This operation is idempotent: calling it on a VDI of type cbt&#95;metadata results in a no&#45;op, and no error will be thrown.

_Signature:_

```
void data_destroy (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |The VDI whose data should be deleted.   |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

_Possible Error Codes:_ `SR_OPERATION_NOT_SUPPORTED`, `VDI_MISSING`, `SR_NOT_ATTACHED`, `SR_HAS_NO_PBDS`, `OPERATION_NOT_ALLOWED`, `VDI_INCOMPATIBLE_TYPE`, `VDI_NO_CBT_METADATA`, `VDI_IN_USE`, `VDI_IS_A_PHYSICAL_DEVICE`

### RPC name: destroy

_Overview:_

Destroy the specified VDI instance.

_Signature:_

```
void destroy (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: disable&#95;cbt

_Overview:_

Disable changed block tracking for the VDI. This call is only allowed on VDIs that support enabling CBT. It is an idempotent operation &#45; disabling CBT for a VDI for which CBT is not enabled results in a no&#45;op, and no error will be thrown.

_Signature:_

```
void disable_cbt (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |The VDI for which CBT should be disabled|

_Minimum Role:_ vm-admin

_Return Type:_ `void`

_Possible Error Codes:_ `SR_OPERATION_NOT_SUPPORTED`, `VDI_MISSING`, `SR_NOT_ATTACHED`, `SR_HAS_NO_PBDS`, `OPERATION_NOT_ALLOWED`, `VDI_INCOMPATIBLE_TYPE`, `VDI_ON_BOOT_MODE_INCOMPATIBLE_WITH_OPERATION`

### RPC name: enable&#95;cbt

_Overview:_

Enable changed block tracking for the VDI. This call is idempotent &#45; enabling CBT for a VDI for which CBT is already enabled results in a no&#45;op, and no error will be thrown.

_Signature:_

```
void enable_cbt (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |The VDI for which CBT should be enabled |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

_Possible Error Codes:_ `SR_OPERATION_NOT_SUPPORTED`, `VDI_MISSING`, `SR_NOT_ATTACHED`, `SR_HAS_NO_PBDS`, `OPERATION_NOT_ALLOWED`, `VDI_INCOMPATIBLE_TYPE`, `VDI_ON_BOOT_MODE_INCOMPATIBLE_WITH_OPERATION`

### RPC name: forget

_Overview:_

Removes a VDI record from the database

_Signature:_

```
void forget (session ref session_ref, VDI ref vdi)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`vdi`                         |The VDI to forget about                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the VDIs known to the system.

_Signature:_

```
VDI ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VDI references to VDI records for all VDIs known to the system.

_Signature:_

```
(VDI ref -> VDI record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(VDI ref -> VDI record) map`

records of all objects

### RPC name: get&#95;allow&#95;caching

_Overview:_

Get the allow&#95;caching field of the given VDI.

_Signature:_

```
bool get_allow_caching (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given VDI.

_Signature:_

```
vdi_operations set get_allowed_operations (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vdi_operations set`

value of the field

### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the VDI instances with the given label.

_Signature:_

```
VDI ref set get_by_name_label (session ref session_ref, string label)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`label`                       |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref set`

references to objects with matching names

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VDI instance with the specified UUID.

_Signature:_

```
VDI ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref`

reference to the object

### RPC name: get&#95;cbt&#95;enabled

_Overview:_

Get the cbt&#95;enabled field of the given VDI.

_Signature:_

```
bool get_cbt_enabled (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;crash&#95;dumps

_Overview:_

Get the crash&#95;dumps field of the given VDI.

_Signature:_

```
crashdump ref set get_crash_dumps (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `crashdump ref set`

value of the field

### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given VDI.

_Signature:_

```
(string -> vdi_operations) map get_current_operations (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> vdi_operations) map`

value of the field

### RPC name: get&#95;is&#95;a&#95;snapshot

_Overview:_

Get the is&#95;a&#95;snapshot field of the given VDI.

_Signature:_

```
bool get_is_a_snapshot (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;is&#95;tools&#95;iso

_Overview:_

Get the is&#95;tools&#95;iso field of the given VDI.

_Signature:_

```
bool get_is_tools_iso (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;location

_Overview:_

Get the location field of the given VDI.

_Signature:_

```
string get_location (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;managed

_Overview:_

Get the managed field of the given VDI.

_Signature:_

```
bool get_managed (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;metadata&#95;latest

_Overview:_

Get the metadata&#95;latest field of the given VDI.

_Signature:_

```
bool get_metadata_latest (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;metadata&#95;of&#95;pool

_Overview:_

Get the metadata&#95;of&#95;pool field of the given VDI.

_Signature:_

```
pool ref get_metadata_of_pool (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pool ref`

value of the field

### RPC name: get&#95;missing

_Overview:_

Get the missing field of the given VDI.

_Signature:_

```
bool get_missing (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given VDI.

_Signature:_

```
string get_name_description (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given VDI.

_Signature:_

```
string get_name_label (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;nbd&#95;info

_Overview:_

Get details specifying how to access this VDI via a Network Block Device server. For each of a set of NBD server addresses on which the VDI is available, the return value set contains a vdi&#95;nbd&#95;server&#95;info object that contains an exportname to request once the NBD connection is established, and connection details for the address. An empty list is returned if there is no network that has a PIF on a host with access to the relevant SR, or if no such network has been assigned an NBD&#45;related purpose in its purpose field. To access the given VDI, any of the vdi&#95;nbd&#95;server&#95;info objects can be used to make a connection to a server, and then the VDI will be available by requesting the exportname.

_Signature:_

```
vdi_nbd_server_info record set get_nbd_info (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |The VDI to access via Network Block Device protocol|

_Minimum Role:_ vm-admin

_Return Type:_ `vdi_nbd_server_info record set`

The details necessary for connecting to the VDI over NBD. This includes an authentication token, so must be treated as sensitive material and must not be sent over insecure networks.

_Possible Error Codes:_ `VDI_INCOMPATIBLE_TYPE`

### RPC name: get&#95;on&#95;boot

_Overview:_

Get the on&#95;boot field of the given VDI.

_Signature:_

```
on_boot get_on_boot (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `on_boot`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given VDI.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;parent

**This message is deprecated.**

_Overview:_

Get the parent field of the given VDI.

_Signature:_

```
VDI ref get_parent (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref`

value of the field

### RPC name: get&#95;physical&#95;utilisation

_Overview:_

Get the physical&#95;utilisation field of the given VDI.

_Signature:_

```
int get_physical_utilisation (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;read&#95;only

_Overview:_

Get the read&#95;only field of the given VDI.

_Signature:_

```
bool get_read_only (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VDI.

_Signature:_

```
VDI record get_record (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI record`

all fields from the object

### RPC name: get&#95;sharable

_Overview:_

Get the sharable field of the given VDI.

_Signature:_

```
bool get_sharable (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;sm&#95;config

_Overview:_

Get the sm&#95;config field of the given VDI.

_Signature:_

```
(string -> string) map get_sm_config (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;snapshot&#95;of

_Overview:_

Get the snapshot&#95;of field of the given VDI.

_Signature:_

```
VDI ref get_snapshot_of (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref`

value of the field

### RPC name: get&#95;snapshot&#95;time

_Overview:_

Get the snapshot&#95;time field of the given VDI.

_Signature:_

```
datetime get_snapshot_time (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: get&#95;snapshots

_Overview:_

Get the snapshots field of the given VDI.

_Signature:_

```
VDI ref set get_snapshots (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref set`

value of the field

### RPC name: get&#95;SR

_Overview:_

Get the SR field of the given VDI.

_Signature:_

```
SR ref get_SR (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

value of the field

### RPC name: get&#95;storage&#95;lock

_Overview:_

Get the storage&#95;lock field of the given VDI.

_Signature:_

```
bool get_storage_lock (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;tags

_Overview:_

Get the tags field of the given VDI.

_Signature:_

```
string set get_tags (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;type

_Overview:_

Get the type field of the given VDI.

_Signature:_

```
vdi_type get_type (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vdi_type`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VDI.

_Signature:_

```
string get_uuid (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;VBDs

_Overview:_

Get the VBDs field of the given VDI.

_Signature:_

```
VBD ref set get_VBDs (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VBD ref set`

value of the field

### RPC name: get&#95;virtual&#95;size

_Overview:_

Get the virtual&#95;size field of the given VDI.

_Signature:_

```
int get_virtual_size (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;xenstore&#95;data

_Overview:_

Get the xenstore&#95;data field of the given VDI.

_Signature:_

```
(string -> string) map get_xenstore_data (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: introduce

_Overview:_

Create a new VDI record in the database only

_Signature:_

```
VDI ref introduce (session ref session_ref, string uuid, string name_label, string name_description, SR ref SR, vdi_type type, bool sharable, bool read_only, (string -> string) map other_config, string location, (string -> string) map xenstore_data, (string -> string) map sm_config, bool managed, int virtual_size, int physical_utilisation, pool ref metadata_of_pool, bool is_a_snapshot, datetime snapshot_time, VDI ref snapshot_of)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |The uuid of the disk to introduce       |
|`string`                      |`name_label`                  |The name of the disk record             |
|`string`                      |`name_description`            |The description of the disk record      |
|`SR ref`                      |`SR`                          |The SR that the VDI is in               |
|`vdi_type`                    |`type`                        |The type of the VDI                     |
|`bool`                        |`sharable`                    |true if this disk may be shared         |
|`bool`                        |`read_only`                   |true if this disk may ONLY be mounted read&#45;only|
|`(string -> string) map`      |`other_config`                |additional configuration                |
|`string`                      |`location`                    |location information                    |
|`(string -> string) map`      |`xenstore_data`               |Data to insert into xenstore            |
|`(string -> string) map`      |`sm_config`                   |Storage&#45;specific config             |
|`bool`                        |`managed`                     |Storage&#45;specific config             |
|`int`                         |`virtual_size`                |Storage&#45;specific config             |
|`int`                         |`physical_utilisation`        |Storage&#45;specific config             |
|`pool ref`                    |`metadata_of_pool`            |Storage&#45;specific config             |
|`bool`                        |`is_a_snapshot`               |Storage&#45;specific config             |
|`datetime`                    |`snapshot_time`               |Storage&#45;specific config             |
|`VDI ref`                     |`snapshot_of`                 |Storage&#45;specific config             |

_Minimum Role:_ vm-admin

_Return Type:_ `VDI ref`

The ref of the newly created VDI record.

_Possible Error Codes:_ `SR_OPERATION_NOT_SUPPORTED`

### RPC name: list&#95;changed&#95;blocks

_Overview:_

Compare two VDIs in 64k block increments and report which blocks differ. This operation is not allowed when vdi&#95;to is attached to a VM.

_Signature:_

```
string list_changed_blocks (session ref session_ref, VDI ref vdi_from, VDI ref vdi_to)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`vdi_from`                    |The first VDI.                          |
|`VDI ref`                     |`vdi_to`                      |The second VDI.                         |

_Minimum Role:_ vm-operator

_Return Type:_ `string`

A base64 string&#45;encoding of the bitmap showing which blocks differ in the two VDIs.

_Possible Error Codes:_ `SR_OPERATION_NOT_SUPPORTED`, `VDI_MISSING`, `SR_NOT_ATTACHED`, `SR_HAS_NO_PBDS`, `VDI_IN_USE`

### RPC name: open&#95;database

_Overview:_

Load the metadata found on the supplied VDI and return a session reference which can be used in API calls to query its contents.

_Signature:_

```
session ref open_database (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |The VDI which contains the database to open|

_Minimum Role:_ pool-operator

_Return Type:_ `session ref`

A session which can be used to query the database

### RPC name: pool&#95;migrate

_Overview:_

Migrate a VDI, which may be attached to a running guest, to a different SR. The destination SR must be visible to the guest.

_Signature:_

```
VDI ref pool_migrate (session ref session_ref, VDI ref vdi, SR ref sr, (string -> string) map options)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`vdi`                         |The VDI to migrate                      |
|`SR ref`                      |`sr`                          |The destination SR                      |
|`(string -> string) map`      |`options`                     |Other parameters                        |

_Minimum Role:_ vm-power-admin

_Return Type:_ `VDI ref`

The new reference of the migrated VDI.

### RPC name: read&#95;database&#95;pool&#95;uuid

_Overview:_

Check the VDI cache for the pool UUID of the database on this VDI.

_Signature:_

```
string read_database_pool_uuid (session ref session_ref, VDI ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |The metadata VDI to look up in the cache.|

_Minimum Role:_ read-only

_Return Type:_ `string`

The cached pool UUID of the database on the VDI.

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given VDI.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, VDI ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;sm&#95;config

_Overview:_

Remove the given key and its corresponding value from the sm&#95;config field of the given VDI.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_sm_config (session ref session_ref, VDI ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;xenstore&#95;data

_Overview:_

Remove the given key and its corresponding value from the xenstore&#95;data field of the given VDI.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_xenstore_data (session ref session_ref, VDI ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: remove&#95;tags

_Overview:_

Remove the given value from the tags field of the given VDI.  If the value is not in that Set, then do nothing.

_Signature:_

```
void remove_tags (session ref session_ref, VDI ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |
|`string`                      |`value`                       |Value to remove                         |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

### RPC name: resize

_Overview:_

Resize the VDI.

_Signature:_

```
void resize (session ref session_ref, VDI ref vdi, int size)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`vdi`                         |The VDI to resize                       |
|`int`                         |`size`                        |The new size of the VDI                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: resize&#95;online

**This message is removed.**

_Overview:_

Resize the VDI which may or may not be attached to running guests.

_Signature:_

```
void resize_online (session ref session_ref, VDI ref vdi, int size)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`vdi`                         |The VDI to resize                       |
|`int`                         |`size`                        |The new size of the VDI                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;allow&#95;caching

_Overview:_

Set the value of the allow&#95;caching parameter. This value can only be changed when the VDI is not attached to a running VM. The caching behaviour is only affected by this flag for VHD&#45;based VDIs that have one parent and no child VHDs. Moreover, caching only takes place when the host running the VM containing this VDI has a nominated SR for local caching.

_Signature:_

```
void set_allow_caching (session ref session_ref, VDI ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |The VDI to modify                       |
|`bool`                        |`value`                       |The value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;name&#95;description

_Overview:_

Set the name description of the VDI. This can only happen when its SR is currently attached.

_Signature:_

```
void set_name_description (session ref session_ref, VDI ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |The VDI to modify                       |
|`string`                      |`value`                       |The name description for the VDI        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;name&#95;label

_Overview:_

Set the name label of the VDI. This can only happen when then its SR is currently attached.

_Signature:_

```
void set_name_label (session ref session_ref, VDI ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |The VDI to modify                       |
|`string`                      |`value`                       |The name lable for the VDI              |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;on&#95;boot

_Overview:_

Set the value of the on&#95;boot parameter. This value can only be changed when the VDI is not attached to a running VM.

_Signature:_

```
void set_on_boot (session ref session_ref, VDI ref self, on_boot value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |The VDI to modify                       |
|`on_boot`                     |`value`                       |The value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given VDI.

_Signature:_

```
void set_other_config (session ref session_ref, VDI ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;read&#95;only

_Overview:_

Sets the VDI's read&#95;only field

_Signature:_

```
void set_read_only (session ref session_ref, VDI ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |The VDI to modify                       |
|`bool`                        |`value`                       |The new value of the VDI's read&#95;only field|

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;sharable

_Overview:_

Sets the VDI's sharable field

_Signature:_

```
void set_sharable (session ref session_ref, VDI ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |The VDI to modify                       |
|`bool`                        |`value`                       |The new value of the VDI's sharable field|

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;sm&#95;config

_Overview:_

Set the sm&#95;config field of the given VDI.

_Signature:_

```
void set_sm_config (session ref session_ref, VDI ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;tags

_Overview:_

Set the tags field of the given VDI.

_Signature:_

```
void set_tags (session ref session_ref, VDI ref self, string set value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |
|`string set`                  |`value`                       |New value to set                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

### RPC name: set&#95;xenstore&#95;data

_Overview:_

Set the xenstore&#95;data field of the given VDI.

_Signature:_

```
void set_xenstore_data (session ref session_ref, VDI ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: snapshot

_Overview:_

Take a read&#45;only snapshot of the VDI, returning a reference to the snapshot. If any driver&#95;params are specified then these are passed through to the storage&#45;specific substrate driver that takes the snapshot. NB the snapshot lives in the same Storage Repository as its parent.

_Signature:_

```
VDI ref snapshot (session ref session_ref, VDI ref vdi, (string -> string) map driver_params)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`vdi`                         |The VDI to snapshot                     |
|`(string -> string) map`      |`driver_params`               |Optional parameters that can be passed through to backend driver in order to specify storage&#45;type&#45;specific snapshot options|

_Minimum Role:_ vm-admin

_Return Type:_ `VDI ref`

The ID of the newly created VDI.

### RPC name: update

_Overview:_

Ask the storage backend to refresh the fields in the VDI object

_Signature:_

```
void update (session ref session_ref, VDI ref vdi)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VDI ref`                     |`vdi`                         |The VDI whose stats &#40;eg size&#41; should be updated|

_Minimum Role:_ vm-admin

_Return Type:_ `void`

_Possible Error Codes:_ `SR_OPERATION_NOT_SUPPORTED`
