---
 layout: doc
---

# Class: VGPU

A virtual GPU &#40;vGPU&#41;

## Fields for class: VGPU

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`compatibility_metadata`|`(string -> string) map`|_RO/runtime_   |VGPU metadata to determine whether a VGPU can migrate between two PGPUs|
|`currently_attached`|`bool`              |_RO/runtime_   |Reflects whether the virtual device is currently connected to a physical device|
|`device`            |`string`            |_RO/runtime_   |Order in which the devices are plugged into the VM|
|`extra_args`        |`string`            |_RW_           |Extra arguments for vGPU and passed to demu|
|`GPU_group`         |`GPU_group ref`     |_RO/runtime_   |GPU group used by the vGPU              |
|`other_config`      |`(string -> string) map`|_RW_           |Additional configuration                |
|`PCI`               |`PCI ref`           |_RO/runtime_   |Device passed trough to VM, either as full device or SR&#45;IOV virtual function|
|`resident_on`       |`PGPU ref`          |_RO/runtime_   |The PGPU on which this VGPU is running  |
|`scheduled_to_be_resident_on`|`PGPU ref`          |_RO/runtime_   |The PGPU on which this VGPU is scheduled to run|
|`type`              |`VGPU_type ref`     |_RO/runtime_   |Preset type for this VGPU               |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`VM`                |`VM ref`            |_RO/runtime_   |VM that owns the vGPU                   |

## RPCs associated with class: VGPU

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given VGPU.

_Signature:_

```
void add_to_other_config (session ref session_ref, VGPU ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: create

_Overview:_

_Signature:_

```
VGPU ref create (session ref session_ref, VM ref VM, GPU_group ref GPU_group, string device, (string -> string) map other_config, VGPU_type ref type)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM ref`                      |`VM`                          |                                        |
|`GPU_group ref`               |`GPU_group`                   |                                        |
|`string`                      |`device`                      |                                        |
|`(string -> string) map`      |`other_config`                |                                        |
|`VGPU_type ref`               |`type`                        |                                        |

_Minimum Role:_ pool-operator

_Return Type:_ `VGPU ref`

The reference of the created VGPU object

### RPC name: destroy

_Overview:_

_Signature:_

```
void destroy (session ref session_ref, VGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU ref`                    |`self`                        |The vGPU to destroy                     |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the VGPUs known to the system.

_Signature:_

```
VGPU ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `VGPU ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VGPU references to VGPU records for all VGPUs known to the system.

_Signature:_

```
(VGPU ref -> VGPU record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(VGPU ref -> VGPU record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VGPU instance with the specified UUID.

_Signature:_

```
VGPU ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VGPU ref`

reference to the object

### RPC name: get&#95;compatibility&#95;metadata

_Overview:_

Get the compatibility&#95;metadata field of the given VGPU.

_Signature:_

```
(string -> string) map get_compatibility_metadata (session ref session_ref, VGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;currently&#95;attached

_Overview:_

Get the currently&#95;attached field of the given VGPU.

_Signature:_

```
bool get_currently_attached (session ref session_ref, VGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;device

_Overview:_

Get the device field of the given VGPU.

_Signature:_

```
string get_device (session ref session_ref, VGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;extra&#95;args

_Overview:_

Get the extra&#95;args field of the given VGPU.

_Signature:_

```
string get_extra_args (session ref session_ref, VGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;GPU&#95;group

_Overview:_

Get the GPU&#95;group field of the given VGPU.

_Signature:_

```
GPU_group ref get_GPU_group (session ref session_ref, VGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `GPU_group ref`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given VGPU.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, VGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;PCI

_Overview:_

Get the PCI field of the given VGPU.

_Signature:_

```
PCI ref get_PCI (session ref session_ref, VGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PCI ref`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VGPU.

_Signature:_

```
VGPU record get_record (session ref session_ref, VGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU record`

all fields from the object

### RPC name: get&#95;resident&#95;on

_Overview:_

Get the resident&#95;on field of the given VGPU.

_Signature:_

```
PGPU ref get_resident_on (session ref session_ref, VGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PGPU ref`

value of the field

### RPC name: get&#95;scheduled&#95;to&#95;be&#95;resident&#95;on

_Overview:_

Get the scheduled&#95;to&#95;be&#95;resident&#95;on field of the given VGPU.

_Signature:_

```
PGPU ref get_scheduled_to_be_resident_on (session ref session_ref, VGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PGPU ref`

value of the field

### RPC name: get&#95;type

_Overview:_

Get the type field of the given VGPU.

_Signature:_

```
VGPU_type ref get_type (session ref session_ref, VGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU_type ref`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VGPU.

_Signature:_

```
string get_uuid (session ref session_ref, VGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;VM

_Overview:_

Get the VM field of the given VGPU.

_Signature:_

```
VM ref get_VM (session ref session_ref, VGPU ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

value of the field

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given VGPU.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, VGPU ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;extra&#95;args

_Overview:_

Set the extra&#95;args field of the given VGPU.

_Signature:_

```
void set_extra_args (session ref session_ref, VGPU ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU ref`                    |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given VGPU.

_Signature:_

```
void set_other_config (session ref session_ref, VGPU ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU ref`                    |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`
