---
 layout: doc
---

# Class: VGPU&#95;type

A type of virtual GPU

## Fields for class: VGPU&#95;type

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`compatible_types_in_vm`|`VGPU_type ref set` |_RO/runtime_   |List of VGPU types which are compatible in one VM|
|`enabled_on_GPU_groups`|`GPU_group ref set` |_RO/runtime_   |List of GPU groups in which at least one have this VGPU type enabled|
|`enabled_on_PGPUs`  |`PGPU ref set`      |_RO/runtime_   |List of PGPUs that have this VGPU type enabled|
|`experimental`      |`bool`              |_RO/constructor_|Indicates whether VGPUs of this type should be considered experimental|
|`framebuffer_size`  |`int`               |_RO/constructor_|Framebuffer size of the VGPU type, in bytes|
|`identifier`        |`string`            |_RO/constructor_|Key used to identify VGPU types and avoid creating duplicates &#45; this field is used internally and not intended for interpretation by API clients|
|`implementation`    |`vgpu_type_implementation`|_RO/constructor_|The internal implementation of this VGPU type|
|`max_heads`         |`int`               |_RO/constructor_|Maximum number of displays supported by the VGPU type|
|`max_resolution_x`  |`int`               |_RO/constructor_|Maximum resolution &#40;width&#41; supported by the VGPU type|
|`max_resolution_y`  |`int`               |_RO/constructor_|Maximum resolution &#40;height&#41; supported by the VGPU type|
|`model_name`        |`string`            |_RO/constructor_|Model name associated with the VGPU type|
|`supported_on_GPU_groups`|`GPU_group ref set` |_RO/runtime_   |List of GPU groups in which at least one PGPU supports this VGPU type|
|`supported_on_PGPUs`|`PGPU ref set`      |_RO/runtime_   |List of PGPUs that support this VGPU type|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`vendor_name`       |`string`            |_RO/constructor_|Name of VGPU vendor                     |
|`VGPUs`             |`VGPU ref set`      |_RO/runtime_   |List of VGPUs of this type              |

## RPCs associated with class: VGPU&#95;type

### RPC name: get&#95;all

_Overview:_

Return a list of all the VGPU&#95;types known to the system.

_Signature:_

```
VGPU_type ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `VGPU_type ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VGPU&#95;type references to VGPU&#95;type records for all VGPU&#95;types known to the system.

_Signature:_

```
(VGPU_type ref -> VGPU_type record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(VGPU_type ref -> VGPU_type record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VGPU&#95;type instance with the specified UUID.

_Signature:_

```
VGPU_type ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VGPU_type ref`

reference to the object

### RPC name: get&#95;compatible&#95;types&#95;in&#95;vm

_Overview:_

Get the compatible&#95;types&#95;in&#95;vm field of the given VGPU&#95;type.

_Signature:_

```
VGPU_type ref set get_compatible_types_in_vm (session ref session_ref, VGPU_type ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU_type ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU_type ref set`

value of the field

### RPC name: get&#95;enabled&#95;on&#95;GPU&#95;groups

_Overview:_

Get the enabled&#95;on&#95;GPU&#95;groups field of the given VGPU&#95;type.

_Signature:_

```
GPU_group ref set get_enabled_on_GPU_groups (session ref session_ref, VGPU_type ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU_type ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `GPU_group ref set`

value of the field

### RPC name: get&#95;enabled&#95;on&#95;PGPUs

_Overview:_

Get the enabled&#95;on&#95;PGPUs field of the given VGPU&#95;type.

_Signature:_

```
PGPU ref set get_enabled_on_PGPUs (session ref session_ref, VGPU_type ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU_type ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PGPU ref set`

value of the field

### RPC name: get&#95;experimental

_Overview:_

Get the experimental field of the given VGPU&#95;type.

_Signature:_

```
bool get_experimental (session ref session_ref, VGPU_type ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU_type ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;framebuffer&#95;size

_Overview:_

Get the framebuffer&#95;size field of the given VGPU&#95;type.

_Signature:_

```
int get_framebuffer_size (session ref session_ref, VGPU_type ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU_type ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;identifier

_Overview:_

Get the identifier field of the given VGPU&#95;type.

_Signature:_

```
string get_identifier (session ref session_ref, VGPU_type ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU_type ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;implementation

_Overview:_

Get the implementation field of the given VGPU&#95;type.

_Signature:_

```
vgpu_type_implementation get_implementation (session ref session_ref, VGPU_type ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU_type ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vgpu_type_implementation`

value of the field

### RPC name: get&#95;max&#95;heads

_Overview:_

Get the max&#95;heads field of the given VGPU&#95;type.

_Signature:_

```
int get_max_heads (session ref session_ref, VGPU_type ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU_type ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;max&#95;resolution&#95;x

_Overview:_

Get the max&#95;resolution&#95;x field of the given VGPU&#95;type.

_Signature:_

```
int get_max_resolution_x (session ref session_ref, VGPU_type ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU_type ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;max&#95;resolution&#95;y

_Overview:_

Get the max&#95;resolution&#95;y field of the given VGPU&#95;type.

_Signature:_

```
int get_max_resolution_y (session ref session_ref, VGPU_type ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU_type ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;model&#95;name

_Overview:_

Get the model&#95;name field of the given VGPU&#95;type.

_Signature:_

```
string get_model_name (session ref session_ref, VGPU_type ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU_type ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VGPU&#95;type.

_Signature:_

```
VGPU_type record get_record (session ref session_ref, VGPU_type ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU_type ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU_type record`

all fields from the object

### RPC name: get&#95;supported&#95;on&#95;GPU&#95;groups

_Overview:_

Get the supported&#95;on&#95;GPU&#95;groups field of the given VGPU&#95;type.

_Signature:_

```
GPU_group ref set get_supported_on_GPU_groups (session ref session_ref, VGPU_type ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU_type ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `GPU_group ref set`

value of the field

### RPC name: get&#95;supported&#95;on&#95;PGPUs

_Overview:_

Get the supported&#95;on&#95;PGPUs field of the given VGPU&#95;type.

_Signature:_

```
PGPU ref set get_supported_on_PGPUs (session ref session_ref, VGPU_type ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU_type ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PGPU ref set`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VGPU&#95;type.

_Signature:_

```
string get_uuid (session ref session_ref, VGPU_type ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU_type ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;vendor&#95;name

_Overview:_

Get the vendor&#95;name field of the given VGPU&#95;type.

_Signature:_

```
string get_vendor_name (session ref session_ref, VGPU_type ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU_type ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;VGPUs

_Overview:_

Get the VGPUs field of the given VGPU&#95;type.

_Signature:_

```
VGPU ref set get_VGPUs (session ref session_ref, VGPU_type ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VGPU_type ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU ref set`

value of the field
