---
 layout: doc
---

# Class: VLAN

A VLAN mux/demux

## Fields for class: VLAN

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`tag`               |`int`               |_RO/constructor_|VLAN tag in use                         |
|`tagged_PIF`        |`PIF ref`           |_RO/constructor_|interface on which traffic is tagged    |
|`untagged_PIF`      |`PIF ref`           |_RO/runtime_   |interface on which traffic is untagged  |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: VLAN

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given VLAN.

_Signature:_

```
void add_to_other_config (session ref session_ref, VLAN ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VLAN ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: create

_Overview:_

Create a VLAN mux/demuxer

_Signature:_

```
VLAN ref create (session ref session_ref, PIF ref tagged_PIF, int tag, network ref network)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`tagged_PIF`                  |PIF which receives the tagged traffic   |
|`int`                         |`tag`                         |VLAN tag to use                         |
|`network ref`                 |`network`                     |Network to receive the untagged traffic |

_Minimum Role:_ pool-operator

_Return Type:_ `VLAN ref`

The reference of the created VLAN object

### RPC name: destroy

_Overview:_

Destroy a VLAN mux/demuxer

_Signature:_

```
void destroy (session ref session_ref, VLAN ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VLAN ref`                    |`self`                        |VLAN mux/demuxer to destroy             |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the VLANs known to the system.

_Signature:_

```
VLAN ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `VLAN ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VLAN references to VLAN records for all VLANs known to the system.

_Signature:_

```
(VLAN ref -> VLAN record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(VLAN ref -> VLAN record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VLAN instance with the specified UUID.

_Signature:_

```
VLAN ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VLAN ref`

reference to the object

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given VLAN.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, VLAN ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VLAN ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VLAN.

_Signature:_

```
VLAN record get_record (session ref session_ref, VLAN ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VLAN ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VLAN record`

all fields from the object

### RPC name: get&#95;tag

_Overview:_

Get the tag field of the given VLAN.

_Signature:_

```
int get_tag (session ref session_ref, VLAN ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VLAN ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;tagged&#95;PIF

_Overview:_

Get the tagged&#95;PIF field of the given VLAN.

_Signature:_

```
PIF ref get_tagged_PIF (session ref session_ref, VLAN ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VLAN ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

value of the field

### RPC name: get&#95;untagged&#95;PIF

_Overview:_

Get the untagged&#95;PIF field of the given VLAN.

_Signature:_

```
PIF ref get_untagged_PIF (session ref session_ref, VLAN ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VLAN ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VLAN.

_Signature:_

```
string get_uuid (session ref session_ref, VLAN ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VLAN ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given VLAN.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, VLAN ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VLAN ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given VLAN.

_Signature:_

```
void set_other_config (session ref session_ref, VLAN ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VLAN ref`                    |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`
