---
 layout: doc
---

# Class: VM&#95;appliance

VM appliance

## Fields for class: VM&#95;appliance

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`allowed_operations`|`vm_appliance_operation set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|`current_operations`|`(string -> vm_appliance_operation) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|`name_description`  |`string`            |_RW_           |a notes field containing human&#45;readable description|
|`name_label`        |`string`            |_RW_           |a human&#45;readable name               |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`VMs`               |`VM ref set`        |_RO/runtime_   |all VMs in this appliance               |

## RPCs associated with class: VM&#95;appliance

### RPC name: assert&#95;can&#95;be&#95;recovered

_Overview:_

Assert whether all SRs required to recover this VM appliance are available.

_Signature:_

```
void assert_can_be_recovered (session ref session_ref, VM_appliance ref self, session ref session_to)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_appliance ref`            |`self`                        |The VM appliance to recover             |
|`session ref`                 |`session_to`                  |The session to which the VM appliance is to be recovered.|

_Minimum Role:_ read-only

_Return Type:_ `void`

_Possible Error Codes:_ `VM_REQUIRES_SR`

### RPC name: clean&#95;shutdown

_Overview:_

Perform a clean shutdown of all the VMs in the appliance

_Signature:_

```
void clean_shutdown (session ref session_ref, VM_appliance ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_appliance ref`            |`self`                        |The VM appliance                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `OPERATION_PARTIALLY_FAILED`

### RPC name: create

_Overview:_

Create a new VM&#95;appliance instance, and return its handle.

_Signature:_

```
VM_appliance ref create (session ref session_ref, VM_appliance record args)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_appliance record`         |`args`                        |All constructor arguments               |

_Minimum Role:_ pool-operator

_Return Type:_ `VM_appliance ref`

reference to the newly created object

### RPC name: destroy

_Overview:_

Destroy the specified VM&#95;appliance instance.

_Signature:_

```
void destroy (session ref session_ref, VM_appliance ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_appliance ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the VM&#95;appliances known to the system.

_Signature:_

```
VM_appliance ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `VM_appliance ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VM&#95;appliance references to VM&#95;appliance records for all VM&#95;appliances known to the system.

_Signature:_

```
(VM_appliance ref -> VM_appliance record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(VM_appliance ref -> VM_appliance record) map`

records of all objects

### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given VM&#95;appliance.

_Signature:_

```
vm_appliance_operation set get_allowed_operations (session ref session_ref, VM_appliance ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_appliance ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vm_appliance_operation set`

value of the field

### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the VM&#95;appliance instances with the given label.

_Signature:_

```
VM_appliance ref set get_by_name_label (session ref session_ref, string label)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`label`                       |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `VM_appliance ref set`

references to objects with matching names

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VM&#95;appliance instance with the specified UUID.

_Signature:_

```
VM_appliance ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VM_appliance ref`

reference to the object

### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given VM&#95;appliance.

_Signature:_

```
(string -> vm_appliance_operation) map get_current_operations (session ref session_ref, VM_appliance ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_appliance ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> vm_appliance_operation) map`

value of the field

### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given VM&#95;appliance.

_Signature:_

```
string get_name_description (session ref session_ref, VM_appliance ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_appliance ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given VM&#95;appliance.

_Signature:_

```
string get_name_label (session ref session_ref, VM_appliance ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_appliance ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VM&#95;appliance.

_Signature:_

```
VM_appliance record get_record (session ref session_ref, VM_appliance ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_appliance ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM_appliance record`

all fields from the object

### RPC name: get&#95;SRs&#95;required&#95;for&#95;recovery

_Overview:_

Get the list of SRs required by the VM appliance to recover.

_Signature:_

```
SR ref set get_SRs_required_for_recovery (session ref session_ref, VM_appliance ref self, session ref session_to)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_appliance ref`            |`self`                        |The VM appliance for which the required list of SRs has to be recovered.|
|`session ref`                 |`session_to`                  |The session to which the list of SRs have to be recovered .|

_Minimum Role:_ read-only

_Return Type:_ `SR ref set`

refs for SRs required to recover the VM

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VM&#95;appliance.

_Signature:_

```
string get_uuid (session ref session_ref, VM_appliance ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_appliance ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;VMs

_Overview:_

Get the VMs field of the given VM&#95;appliance.

_Signature:_

```
VM ref set get_VMs (session ref session_ref, VM_appliance ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_appliance ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref set`

value of the field

### RPC name: hard&#95;shutdown

_Overview:_

Perform a hard shutdown of all the VMs in the appliance

_Signature:_

```
void hard_shutdown (session ref session_ref, VM_appliance ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_appliance ref`            |`self`                        |The VM appliance                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `OPERATION_PARTIALLY_FAILED`

### RPC name: recover

_Overview:_

Recover the VM appliance

_Signature:_

```
void recover (session ref session_ref, VM_appliance ref self, session ref session_to, bool force)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_appliance ref`            |`self`                        |The VM appliance to recover             |
|`session ref`                 |`session_to`                  |The session to which the VM appliance is to be recovered.|
|`bool`                        |`force`                       |Whether the VMs should replace newer versions of themselves.|

_Minimum Role:_ read-only

_Return Type:_ `void`

_Possible Error Codes:_ `VM_REQUIRES_SR`

### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given VM&#95;appliance.

_Signature:_

```
void set_name_description (session ref session_ref, VM_appliance ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_appliance ref`            |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given VM&#95;appliance.

_Signature:_

```
void set_name_label (session ref session_ref, VM_appliance ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_appliance ref`            |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: shutdown

_Overview:_

For each VM in the appliance, try to shut it down cleanly. If this fails, perform a hard shutdown of the VM.

_Signature:_

```
void shutdown (session ref session_ref, VM_appliance ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_appliance ref`            |`self`                        |The VM appliance                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `OPERATION_PARTIALLY_FAILED`

### RPC name: start

_Overview:_

Start all VMs in the appliance

_Signature:_

```
void start (session ref session_ref, VM_appliance ref self, bool paused)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_appliance ref`            |`self`                        |The VM appliance                        |
|`bool`                        |`paused`                      |Instantiate all VMs belonging to this appliance in paused state if set to true.|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `OPERATION_PARTIALLY_FAILED`
