---
 layout: doc
---

# Class: VM&#95;guest&#95;metrics

The metrics reported by the guest &#40;as opposed to inferred from outside&#41;

## Fields for class: VM&#95;guest&#95;metrics

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`can_use_hotplug_vbd`|`tristate_type`     |_RO/runtime_   |The guest's statement of whether it supports VBD hotplug, i.e. whether it is capable of responding immediately to instantiation of a new VBD by bringing online a new PV block device. If the guest states that it is not capable, then the VBD plug and unplug operations will not be allowed while the guest is running.|
|`can_use_hotplug_vif`|`tristate_type`     |_RO/runtime_   |The guest's statement of whether it supports VIF hotplug, i.e. whether it is capable of responding immediately to instantiation of a new VIF by bringing online a new PV network device. If the guest states that it is not capable, then the VIF plug and unplug operations will not be allowed while the guest is running.|
|`disks`             |`(string -> string) map`|_RO/runtime_   |**Removed.** This field exists but has no data.      |
|`last_updated`      |`datetime`          |_RO/runtime_   |Time at which this information was last updated|
|`live`              |`bool`              |_RO/runtime_   |True if the guest is sending heartbeat messages via the guest agent|
|`memory`            |`(string -> string) map`|_RO/runtime_   |**Removed.** This field exists but has no data. Use the memory and memory&#95;internal&#95;free RRD data&#45;sources instead.|
|`networks`          |`(string -> string) map`|_RO/runtime_   |network configuration                   |
|`os_version`        |`(string -> string) map`|_RO/runtime_   |version of the OS                       |
|`other`             |`(string -> string) map`|_RO/runtime_   |anything else                           |
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`PV_drivers_detected`|`bool`              |_RO/runtime_   |At least one of the guest's devices has successfully connected to the backend.|
|`PV_drivers_up_to_date`|`bool`              |_RO/runtime_   |**Deprecated.** Logically equivalent to PV&#95;drivers&#95;detected|
|`PV_drivers_version`|`(string -> string) map`|_RO/runtime_   |version of the PV drivers               |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: VM&#95;guest&#95;metrics

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
void add_to_other_config (session ref session_ref, VM_guest_metrics ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_guest_metrics ref`        |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the VM&#95;guest&#95;metrics instances known to the system.

_Signature:_

```
VM_guest_metrics ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `VM_guest_metrics ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VM&#95;guest&#95;metrics references to VM&#95;guest&#95;metrics records for all VM&#95;guest&#95;metrics instances known to the system.

_Signature:_

```
(VM_guest_metrics ref -> VM_guest_metrics record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(VM_guest_metrics ref -> VM_guest_metrics record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VM&#95;guest&#95;metrics instance with the specified UUID.

_Signature:_

```
VM_guest_metrics ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VM_guest_metrics ref`

reference to the object

### RPC name: get&#95;can&#95;use&#95;hotplug&#95;vbd

_Overview:_

Get the can&#95;use&#95;hotplug&#95;vbd field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
tristate_type get_can_use_hotplug_vbd (session ref session_ref, VM_guest_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_guest_metrics ref`        |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `tristate_type`

value of the field

### RPC name: get&#95;can&#95;use&#95;hotplug&#95;vif

_Overview:_

Get the can&#95;use&#95;hotplug&#95;vif field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
tristate_type get_can_use_hotplug_vif (session ref session_ref, VM_guest_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_guest_metrics ref`        |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `tristate_type`

value of the field

### RPC name: get&#95;disks

**This message is removed.**

_Overview:_

Get the disks field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
(string -> string) map get_disks (session ref session_ref, VM_guest_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_guest_metrics ref`        |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;last&#95;updated

_Overview:_

Get the last&#95;updated field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
datetime get_last_updated (session ref session_ref, VM_guest_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_guest_metrics ref`        |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: get&#95;live

_Overview:_

Get the live field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
bool get_live (session ref session_ref, VM_guest_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_guest_metrics ref`        |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;memory

**This message is removed.**

_Overview:_

Get the memory field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
(string -> string) map get_memory (session ref session_ref, VM_guest_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_guest_metrics ref`        |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;networks

_Overview:_

Get the networks field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
(string -> string) map get_networks (session ref session_ref, VM_guest_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_guest_metrics ref`        |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;os&#95;version

_Overview:_

Get the os&#95;version field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
(string -> string) map get_os_version (session ref session_ref, VM_guest_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_guest_metrics ref`        |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;other

_Overview:_

Get the other field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
(string -> string) map get_other (session ref session_ref, VM_guest_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_guest_metrics ref`        |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, VM_guest_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_guest_metrics ref`        |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;PV&#95;drivers&#95;detected

_Overview:_

Get the PV&#95;drivers&#95;detected field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
bool get_PV_drivers_detected (session ref session_ref, VM_guest_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_guest_metrics ref`        |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;PV&#95;drivers&#95;up&#95;to&#95;date

**This message is deprecated.**

_Overview:_

Get the PV&#95;drivers&#95;up&#95;to&#95;date field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
bool get_PV_drivers_up_to_date (session ref session_ref, VM_guest_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_guest_metrics ref`        |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;PV&#95;drivers&#95;version

_Overview:_

Get the PV&#95;drivers&#95;version field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
(string -> string) map get_PV_drivers_version (session ref session_ref, VM_guest_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_guest_metrics ref`        |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VM&#95;guest&#95;metrics.

_Signature:_

```
VM_guest_metrics record get_record (session ref session_ref, VM_guest_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_guest_metrics ref`        |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM_guest_metrics record`

all fields from the object

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
string get_uuid (session ref session_ref, VM_guest_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_guest_metrics ref`        |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given VM&#95;guest&#95;metrics.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, VM_guest_metrics ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_guest_metrics ref`        |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
void set_other_config (session ref session_ref, VM_guest_metrics ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_guest_metrics ref`        |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`
